/*
 * Generated by gdbus-codegen 2.56.0. DO NOT EDIT.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from.
 */

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#include "logind-session.h"

#include <string.h>
#ifdef G_OS_UNIX
#  include <gio/gunixfdlist.h>
#endif

typedef struct
{
  GDBusArgInfo parent_struct;
  gboolean use_gvariant;
} _ExtendedGDBusArgInfo;

typedef struct
{
  GDBusMethodInfo parent_struct;
  const gchar *signal_name;
  gboolean pass_fdlist;
} _ExtendedGDBusMethodInfo;

typedef struct
{
  GDBusSignalInfo parent_struct;
  const gchar *signal_name;
} _ExtendedGDBusSignalInfo;

typedef struct
{
  GDBusPropertyInfo parent_struct;
  const gchar *hyphen_name;
  gboolean use_gvariant;
} _ExtendedGDBusPropertyInfo;

typedef struct
{
  GDBusInterfaceInfo parent_struct;
  const gchar *hyphen_name;
} _ExtendedGDBusInterfaceInfo;

typedef struct
{
  const _ExtendedGDBusPropertyInfo *info;
  guint prop_id;
  GValue orig_value; /* the value before the change */
} ChangedProperty;

static void
_changed_property_free (ChangedProperty *data)
{
  g_value_unset (&data->orig_value);
  g_free (data);
}

static gboolean
_g_strv_equal0 (gchar **a, gchar **b)
{
  gboolean ret = FALSE;
  guint n;
  if (a == NULL && b == NULL)
    {
      ret = TRUE;
      goto out;
    }
  if (a == NULL || b == NULL)
    goto out;
  if (g_strv_length (a) != g_strv_length (b))
    goto out;
  for (n = 0; a[n] != NULL; n++)
    if (g_strcmp0 (a[n], b[n]) != 0)
      goto out;
  ret = TRUE;
out:
  return ret;
}

static gboolean
_g_variant_equal0 (GVariant *a, GVariant *b)
{
  gboolean ret = FALSE;
  if (a == NULL && b == NULL)
    {
      ret = TRUE;
      goto out;
    }
  if (a == NULL || b == NULL)
    goto out;
  ret = g_variant_equal (a, b);
out:
  return ret;
}

G_GNUC_UNUSED static gboolean
_g_value_equal (const GValue *a, const GValue *b)
{
  gboolean ret = FALSE;
  g_assert (G_VALUE_TYPE (a) == G_VALUE_TYPE (b));
  switch (G_VALUE_TYPE (a))
    {
      case G_TYPE_BOOLEAN:
        ret = (g_value_get_boolean (a) == g_value_get_boolean (b));
        break;
      case G_TYPE_UCHAR:
        ret = (g_value_get_uchar (a) == g_value_get_uchar (b));
        break;
      case G_TYPE_INT:
        ret = (g_value_get_int (a) == g_value_get_int (b));
        break;
      case G_TYPE_UINT:
        ret = (g_value_get_uint (a) == g_value_get_uint (b));
        break;
      case G_TYPE_INT64:
        ret = (g_value_get_int64 (a) == g_value_get_int64 (b));
        break;
      case G_TYPE_UINT64:
        ret = (g_value_get_uint64 (a) == g_value_get_uint64 (b));
        break;
      case G_TYPE_DOUBLE:
        {
          /* Avoid -Wfloat-equal warnings by doing a direct bit compare */
          gdouble da = g_value_get_double (a);
          gdouble db = g_value_get_double (b);
          ret = memcmp (&da, &db, sizeof (gdouble)) == 0;
        }
        break;
      case G_TYPE_STRING:
        ret = (g_strcmp0 (g_value_get_string (a), g_value_get_string (b)) == 0);
        break;
      case G_TYPE_VARIANT:
        ret = _g_variant_equal0 (g_value_get_variant (a), g_value_get_variant (b));
        break;
      default:
        if (G_VALUE_TYPE (a) == G_TYPE_STRV)
          ret = _g_strv_equal0 (g_value_get_boxed (a), g_value_get_boxed (b));
        else
          g_critical ("_g_value_equal() does not handle type %s", g_type_name (G_VALUE_TYPE (a)));
        break;
    }
  return ret;
}

/* ------------------------------------------------------------------------
 * Code for interface org.freedesktop.login1.Session
 * ------------------------------------------------------------------------
 */

/**
 * SECTION:LogindSession
 * @title: LogindSession
 * @short_description: Generated C code for the org.freedesktop.login1.Session D-Bus interface
 *
 * This section contains code for working with the <link linkend="gdbus-interface-org-freedesktop-login1-Session.top_of_page">org.freedesktop.login1.Session</link> D-Bus interface in C.
 */

/* ---- Introspection data for org.freedesktop.login1.Session ---- */

static const _ExtendedGDBusMethodInfo _logind_session_method_info_terminate =
{
  {
    -1,
    (gchar *) "Terminate",
    NULL,
    NULL,
    NULL
  },
  "handle-terminate",
  FALSE
};

static const _ExtendedGDBusMethodInfo _logind_session_method_info_activate =
{
  {
    -1,
    (gchar *) "Activate",
    NULL,
    NULL,
    NULL
  },
  "handle-activate",
  FALSE
};

static const _ExtendedGDBusMethodInfo _logind_session_method_info_lock =
{
  {
    -1,
    (gchar *) "Lock",
    NULL,
    NULL,
    NULL
  },
  "handle-lock",
  FALSE
};

static const _ExtendedGDBusMethodInfo _logind_session_method_info_unlock =
{
  {
    -1,
    (gchar *) "Unlock",
    NULL,
    NULL,
    NULL
  },
  "handle-unlock",
  FALSE
};

static const _ExtendedGDBusArgInfo _logind_session_method_info_set_idle_hint_IN_ARG_unnamed_arg0 =
{
  {
    -1,
    (gchar *) "unnamed_arg0",
    (gchar *) "b",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _logind_session_method_info_set_idle_hint_IN_ARG_pointers[] =
{
  &_logind_session_method_info_set_idle_hint_IN_ARG_unnamed_arg0,
  NULL
};

static const _ExtendedGDBusMethodInfo _logind_session_method_info_set_idle_hint =
{
  {
    -1,
    (gchar *) "SetIdleHint",
    (GDBusArgInfo **) &_logind_session_method_info_set_idle_hint_IN_ARG_pointers,
    NULL,
    NULL
  },
  "handle-set-idle-hint",
  FALSE
};

static const _ExtendedGDBusArgInfo _logind_session_method_info_set_locked_hint_IN_ARG_unnamed_arg0 =
{
  {
    -1,
    (gchar *) "unnamed_arg0",
    (gchar *) "b",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _logind_session_method_info_set_locked_hint_IN_ARG_pointers[] =
{
  &_logind_session_method_info_set_locked_hint_IN_ARG_unnamed_arg0,
  NULL
};

static const _ExtendedGDBusMethodInfo _logind_session_method_info_set_locked_hint =
{
  {
    -1,
    (gchar *) "SetLockedHint",
    (GDBusArgInfo **) &_logind_session_method_info_set_locked_hint_IN_ARG_pointers,
    NULL,
    NULL
  },
  "handle-set-locked-hint",
  FALSE
};

static const _ExtendedGDBusArgInfo _logind_session_method_info_kill_IN_ARG_unnamed_arg0 =
{
  {
    -1,
    (gchar *) "unnamed_arg0",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _logind_session_method_info_kill_IN_ARG_unnamed_arg1 =
{
  {
    -1,
    (gchar *) "unnamed_arg1",
    (gchar *) "i",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _logind_session_method_info_kill_IN_ARG_pointers[] =
{
  &_logind_session_method_info_kill_IN_ARG_unnamed_arg0,
  &_logind_session_method_info_kill_IN_ARG_unnamed_arg1,
  NULL
};

static const _ExtendedGDBusMethodInfo _logind_session_method_info_kill =
{
  {
    -1,
    (gchar *) "Kill",
    (GDBusArgInfo **) &_logind_session_method_info_kill_IN_ARG_pointers,
    NULL,
    NULL
  },
  "handle-kill",
  FALSE
};

static const _ExtendedGDBusArgInfo _logind_session_method_info_take_control_IN_ARG_unnamed_arg0 =
{
  {
    -1,
    (gchar *) "unnamed_arg0",
    (gchar *) "b",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _logind_session_method_info_take_control_IN_ARG_pointers[] =
{
  &_logind_session_method_info_take_control_IN_ARG_unnamed_arg0,
  NULL
};

static const _ExtendedGDBusMethodInfo _logind_session_method_info_take_control =
{
  {
    -1,
    (gchar *) "TakeControl",
    (GDBusArgInfo **) &_logind_session_method_info_take_control_IN_ARG_pointers,
    NULL,
    NULL
  },
  "handle-take-control",
  FALSE
};

static const _ExtendedGDBusMethodInfo _logind_session_method_info_release_control =
{
  {
    -1,
    (gchar *) "ReleaseControl",
    NULL,
    NULL,
    NULL
  },
  "handle-release-control",
  FALSE
};

static const _ExtendedGDBusArgInfo _logind_session_method_info_take_device_IN_ARG_unnamed_arg0 =
{
  {
    -1,
    (gchar *) "unnamed_arg0",
    (gchar *) "u",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _logind_session_method_info_take_device_IN_ARG_unnamed_arg1 =
{
  {
    -1,
    (gchar *) "unnamed_arg1",
    (gchar *) "u",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _logind_session_method_info_take_device_IN_ARG_pointers[] =
{
  &_logind_session_method_info_take_device_IN_ARG_unnamed_arg0,
  &_logind_session_method_info_take_device_IN_ARG_unnamed_arg1,
  NULL
};

static const _ExtendedGDBusArgInfo _logind_session_method_info_take_device_OUT_ARG_unnamed_arg2 =
{
  {
    -1,
    (gchar *) "unnamed_arg2",
    (gchar *) "h",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _logind_session_method_info_take_device_OUT_ARG_unnamed_arg3 =
{
  {
    -1,
    (gchar *) "unnamed_arg3",
    (gchar *) "b",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _logind_session_method_info_take_device_OUT_ARG_pointers[] =
{
  &_logind_session_method_info_take_device_OUT_ARG_unnamed_arg2,
  &_logind_session_method_info_take_device_OUT_ARG_unnamed_arg3,
  NULL
};

static const _ExtendedGDBusMethodInfo _logind_session_method_info_take_device =
{
  {
    -1,
    (gchar *) "TakeDevice",
    (GDBusArgInfo **) &_logind_session_method_info_take_device_IN_ARG_pointers,
    (GDBusArgInfo **) &_logind_session_method_info_take_device_OUT_ARG_pointers,
    NULL
  },
  "handle-take-device",
  FALSE
};

static const _ExtendedGDBusArgInfo _logind_session_method_info_release_device_IN_ARG_unnamed_arg0 =
{
  {
    -1,
    (gchar *) "unnamed_arg0",
    (gchar *) "u",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _logind_session_method_info_release_device_IN_ARG_unnamed_arg1 =
{
  {
    -1,
    (gchar *) "unnamed_arg1",
    (gchar *) "u",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _logind_session_method_info_release_device_IN_ARG_pointers[] =
{
  &_logind_session_method_info_release_device_IN_ARG_unnamed_arg0,
  &_logind_session_method_info_release_device_IN_ARG_unnamed_arg1,
  NULL
};

static const _ExtendedGDBusMethodInfo _logind_session_method_info_release_device =
{
  {
    -1,
    (gchar *) "ReleaseDevice",
    (GDBusArgInfo **) &_logind_session_method_info_release_device_IN_ARG_pointers,
    NULL,
    NULL
  },
  "handle-release-device",
  FALSE
};

static const _ExtendedGDBusArgInfo _logind_session_method_info_pause_device_complete_IN_ARG_unnamed_arg0 =
{
  {
    -1,
    (gchar *) "unnamed_arg0",
    (gchar *) "u",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _logind_session_method_info_pause_device_complete_IN_ARG_unnamed_arg1 =
{
  {
    -1,
    (gchar *) "unnamed_arg1",
    (gchar *) "u",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _logind_session_method_info_pause_device_complete_IN_ARG_pointers[] =
{
  &_logind_session_method_info_pause_device_complete_IN_ARG_unnamed_arg0,
  &_logind_session_method_info_pause_device_complete_IN_ARG_unnamed_arg1,
  NULL
};

static const _ExtendedGDBusMethodInfo _logind_session_method_info_pause_device_complete =
{
  {
    -1,
    (gchar *) "PauseDeviceComplete",
    (GDBusArgInfo **) &_logind_session_method_info_pause_device_complete_IN_ARG_pointers,
    NULL,
    NULL
  },
  "handle-pause-device-complete",
  FALSE
};

static const _ExtendedGDBusMethodInfo * const _logind_session_method_info_pointers[] =
{
  &_logind_session_method_info_terminate,
  &_logind_session_method_info_activate,
  &_logind_session_method_info_lock,
  &_logind_session_method_info_unlock,
  &_logind_session_method_info_set_idle_hint,
  &_logind_session_method_info_set_locked_hint,
  &_logind_session_method_info_kill,
  &_logind_session_method_info_take_control,
  &_logind_session_method_info_release_control,
  &_logind_session_method_info_take_device,
  &_logind_session_method_info_release_device,
  &_logind_session_method_info_pause_device_complete,
  NULL
};

static const _ExtendedGDBusArgInfo _logind_session_signal_info_pause_device_ARG_unnamed_arg0 =
{
  {
    -1,
    (gchar *) "unnamed_arg0",
    (gchar *) "u",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _logind_session_signal_info_pause_device_ARG_unnamed_arg1 =
{
  {
    -1,
    (gchar *) "unnamed_arg1",
    (gchar *) "u",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _logind_session_signal_info_pause_device_ARG_unnamed_arg2 =
{
  {
    -1,
    (gchar *) "unnamed_arg2",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _logind_session_signal_info_pause_device_ARG_pointers[] =
{
  &_logind_session_signal_info_pause_device_ARG_unnamed_arg0,
  &_logind_session_signal_info_pause_device_ARG_unnamed_arg1,
  &_logind_session_signal_info_pause_device_ARG_unnamed_arg2,
  NULL
};

static const _ExtendedGDBusSignalInfo _logind_session_signal_info_pause_device =
{
  {
    -1,
    (gchar *) "PauseDevice",
    (GDBusArgInfo **) &_logind_session_signal_info_pause_device_ARG_pointers,
    NULL
  },
  "pause-device"
};

static const _ExtendedGDBusArgInfo _logind_session_signal_info_resume_device_ARG_unnamed_arg0 =
{
  {
    -1,
    (gchar *) "unnamed_arg0",
    (gchar *) "u",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _logind_session_signal_info_resume_device_ARG_unnamed_arg1 =
{
  {
    -1,
    (gchar *) "unnamed_arg1",
    (gchar *) "u",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _logind_session_signal_info_resume_device_ARG_unnamed_arg2 =
{
  {
    -1,
    (gchar *) "unnamed_arg2",
    (gchar *) "h",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _logind_session_signal_info_resume_device_ARG_pointers[] =
{
  &_logind_session_signal_info_resume_device_ARG_unnamed_arg0,
  &_logind_session_signal_info_resume_device_ARG_unnamed_arg1,
  &_logind_session_signal_info_resume_device_ARG_unnamed_arg2,
  NULL
};

static const _ExtendedGDBusSignalInfo _logind_session_signal_info_resume_device =
{
  {
    -1,
    (gchar *) "ResumeDevice",
    (GDBusArgInfo **) &_logind_session_signal_info_resume_device_ARG_pointers,
    NULL
  },
  "resume-device"
};

static const _ExtendedGDBusSignalInfo _logind_session_signal_info_lock =
{
  {
    -1,
    (gchar *) "Lock",
    NULL,
    NULL
  },
  "lock"
};

static const _ExtendedGDBusSignalInfo _logind_session_signal_info_unlock =
{
  {
    -1,
    (gchar *) "Unlock",
    NULL,
    NULL
  },
  "unlock"
};

static const _ExtendedGDBusSignalInfo * const _logind_session_signal_info_pointers[] =
{
  &_logind_session_signal_info_pause_device,
  &_logind_session_signal_info_resume_device,
  &_logind_session_signal_info_lock,
  &_logind_session_signal_info_unlock,
  NULL
};

static const GDBusAnnotationInfo _logind_session_property_id_annotation_info_0 =
{
  -1,
  (gchar *) "org.freedesktop.DBus.Property.EmitsChangedSignal",
  (gchar *) "const",
  NULL
};

static const GDBusAnnotationInfo * const _logind_session_property_id_annotation_info_pointers[] =
{
  &_logind_session_property_id_annotation_info_0,
  NULL
};

static const _ExtendedGDBusPropertyInfo _logind_session_property_info_id =
{
  {
    -1,
    (gchar *) "Id",
    (gchar *) "s",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    (GDBusAnnotationInfo **) &_logind_session_property_id_annotation_info_pointers
  },
  "id",
  FALSE
};

static const GDBusAnnotationInfo _logind_session_property_user_annotation_info_0 =
{
  -1,
  (gchar *) "org.freedesktop.DBus.Property.EmitsChangedSignal",
  (gchar *) "const",
  NULL
};

static const GDBusAnnotationInfo * const _logind_session_property_user_annotation_info_pointers[] =
{
  &_logind_session_property_user_annotation_info_0,
  NULL
};

static const _ExtendedGDBusPropertyInfo _logind_session_property_info_user =
{
  {
    -1,
    (gchar *) "User",
    (gchar *) "(uo)",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    (GDBusAnnotationInfo **) &_logind_session_property_user_annotation_info_pointers
  },
  "user",
  FALSE
};

static const GDBusAnnotationInfo _logind_session_property_name_annotation_info_0 =
{
  -1,
  (gchar *) "org.freedesktop.DBus.Property.EmitsChangedSignal",
  (gchar *) "const",
  NULL
};

static const GDBusAnnotationInfo * const _logind_session_property_name_annotation_info_pointers[] =
{
  &_logind_session_property_name_annotation_info_0,
  NULL
};

static const _ExtendedGDBusPropertyInfo _logind_session_property_info_name =
{
  {
    -1,
    (gchar *) "Name",
    (gchar *) "s",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    (GDBusAnnotationInfo **) &_logind_session_property_name_annotation_info_pointers
  },
  "name",
  FALSE
};

static const GDBusAnnotationInfo _logind_session_property_timestamp_annotation_info_0 =
{
  -1,
  (gchar *) "org.freedesktop.DBus.Property.EmitsChangedSignal",
  (gchar *) "const",
  NULL
};

static const GDBusAnnotationInfo * const _logind_session_property_timestamp_annotation_info_pointers[] =
{
  &_logind_session_property_timestamp_annotation_info_0,
  NULL
};

static const _ExtendedGDBusPropertyInfo _logind_session_property_info_timestamp =
{
  {
    -1,
    (gchar *) "Timestamp",
    (gchar *) "t",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    (GDBusAnnotationInfo **) &_logind_session_property_timestamp_annotation_info_pointers
  },
  "timestamp",
  FALSE
};

static const GDBusAnnotationInfo _logind_session_property_timestamp_monotonic_annotation_info_0 =
{
  -1,
  (gchar *) "org.freedesktop.DBus.Property.EmitsChangedSignal",
  (gchar *) "const",
  NULL
};

static const GDBusAnnotationInfo * const _logind_session_property_timestamp_monotonic_annotation_info_pointers[] =
{
  &_logind_session_property_timestamp_monotonic_annotation_info_0,
  NULL
};

static const _ExtendedGDBusPropertyInfo _logind_session_property_info_timestamp_monotonic =
{
  {
    -1,
    (gchar *) "TimestampMonotonic",
    (gchar *) "t",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    (GDBusAnnotationInfo **) &_logind_session_property_timestamp_monotonic_annotation_info_pointers
  },
  "timestamp-monotonic",
  FALSE
};

static const GDBusAnnotationInfo _logind_session_property_vtnr_annotation_info_0 =
{
  -1,
  (gchar *) "org.freedesktop.DBus.Property.EmitsChangedSignal",
  (gchar *) "const",
  NULL
};

static const GDBusAnnotationInfo * const _logind_session_property_vtnr_annotation_info_pointers[] =
{
  &_logind_session_property_vtnr_annotation_info_0,
  NULL
};

static const _ExtendedGDBusPropertyInfo _logind_session_property_info_vtnr =
{
  {
    -1,
    (gchar *) "VTNr",
    (gchar *) "u",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    (GDBusAnnotationInfo **) &_logind_session_property_vtnr_annotation_info_pointers
  },
  "vtnr",
  FALSE
};

static const GDBusAnnotationInfo _logind_session_property_seat_annotation_info_0 =
{
  -1,
  (gchar *) "org.freedesktop.DBus.Property.EmitsChangedSignal",
  (gchar *) "const",
  NULL
};

static const GDBusAnnotationInfo * const _logind_session_property_seat_annotation_info_pointers[] =
{
  &_logind_session_property_seat_annotation_info_0,
  NULL
};

static const _ExtendedGDBusPropertyInfo _logind_session_property_info_seat =
{
  {
    -1,
    (gchar *) "Seat",
    (gchar *) "(so)",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    (GDBusAnnotationInfo **) &_logind_session_property_seat_annotation_info_pointers
  },
  "seat",
  FALSE
};

static const GDBusAnnotationInfo _logind_session_property_tty_annotation_info_0 =
{
  -1,
  (gchar *) "org.freedesktop.DBus.Property.EmitsChangedSignal",
  (gchar *) "const",
  NULL
};

static const GDBusAnnotationInfo * const _logind_session_property_tty_annotation_info_pointers[] =
{
  &_logind_session_property_tty_annotation_info_0,
  NULL
};

static const _ExtendedGDBusPropertyInfo _logind_session_property_info_tty =
{
  {
    -1,
    (gchar *) "TTY",
    (gchar *) "s",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    (GDBusAnnotationInfo **) &_logind_session_property_tty_annotation_info_pointers
  },
  "tty",
  FALSE
};

static const GDBusAnnotationInfo _logind_session_property_display_annotation_info_0 =
{
  -1,
  (gchar *) "org.freedesktop.DBus.Property.EmitsChangedSignal",
  (gchar *) "const",
  NULL
};

static const GDBusAnnotationInfo * const _logind_session_property_display_annotation_info_pointers[] =
{
  &_logind_session_property_display_annotation_info_0,
  NULL
};

static const _ExtendedGDBusPropertyInfo _logind_session_property_info_display =
{
  {
    -1,
    (gchar *) "Display",
    (gchar *) "s",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    (GDBusAnnotationInfo **) &_logind_session_property_display_annotation_info_pointers
  },
  "display",
  FALSE
};

static const GDBusAnnotationInfo _logind_session_property_remote_annotation_info_0 =
{
  -1,
  (gchar *) "org.freedesktop.DBus.Property.EmitsChangedSignal",
  (gchar *) "const",
  NULL
};

static const GDBusAnnotationInfo * const _logind_session_property_remote_annotation_info_pointers[] =
{
  &_logind_session_property_remote_annotation_info_0,
  NULL
};

static const _ExtendedGDBusPropertyInfo _logind_session_property_info_remote =
{
  {
    -1,
    (gchar *) "Remote",
    (gchar *) "b",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    (GDBusAnnotationInfo **) &_logind_session_property_remote_annotation_info_pointers
  },
  "remote",
  FALSE
};

static const GDBusAnnotationInfo _logind_session_property_remote_host_annotation_info_0 =
{
  -1,
  (gchar *) "org.freedesktop.DBus.Property.EmitsChangedSignal",
  (gchar *) "const",
  NULL
};

static const GDBusAnnotationInfo * const _logind_session_property_remote_host_annotation_info_pointers[] =
{
  &_logind_session_property_remote_host_annotation_info_0,
  NULL
};

static const _ExtendedGDBusPropertyInfo _logind_session_property_info_remote_host =
{
  {
    -1,
    (gchar *) "RemoteHost",
    (gchar *) "s",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    (GDBusAnnotationInfo **) &_logind_session_property_remote_host_annotation_info_pointers
  },
  "remote-host",
  FALSE
};

static const GDBusAnnotationInfo _logind_session_property_remote_user_annotation_info_0 =
{
  -1,
  (gchar *) "org.freedesktop.DBus.Property.EmitsChangedSignal",
  (gchar *) "const",
  NULL
};

static const GDBusAnnotationInfo * const _logind_session_property_remote_user_annotation_info_pointers[] =
{
  &_logind_session_property_remote_user_annotation_info_0,
  NULL
};

static const _ExtendedGDBusPropertyInfo _logind_session_property_info_remote_user =
{
  {
    -1,
    (gchar *) "RemoteUser",
    (gchar *) "s",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    (GDBusAnnotationInfo **) &_logind_session_property_remote_user_annotation_info_pointers
  },
  "remote-user",
  FALSE
};

static const GDBusAnnotationInfo _logind_session_property_service_annotation_info_0 =
{
  -1,
  (gchar *) "org.freedesktop.DBus.Property.EmitsChangedSignal",
  (gchar *) "const",
  NULL
};

static const GDBusAnnotationInfo * const _logind_session_property_service_annotation_info_pointers[] =
{
  &_logind_session_property_service_annotation_info_0,
  NULL
};

static const _ExtendedGDBusPropertyInfo _logind_session_property_info_service =
{
  {
    -1,
    (gchar *) "Service",
    (gchar *) "s",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    (GDBusAnnotationInfo **) &_logind_session_property_service_annotation_info_pointers
  },
  "service",
  FALSE
};

static const GDBusAnnotationInfo _logind_session_property_desktop_annotation_info_0 =
{
  -1,
  (gchar *) "org.freedesktop.DBus.Property.EmitsChangedSignal",
  (gchar *) "const",
  NULL
};

static const GDBusAnnotationInfo * const _logind_session_property_desktop_annotation_info_pointers[] =
{
  &_logind_session_property_desktop_annotation_info_0,
  NULL
};

static const _ExtendedGDBusPropertyInfo _logind_session_property_info_desktop =
{
  {
    -1,
    (gchar *) "Desktop",
    (gchar *) "s",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    (GDBusAnnotationInfo **) &_logind_session_property_desktop_annotation_info_pointers
  },
  "desktop",
  FALSE
};

static const GDBusAnnotationInfo _logind_session_property_scope_annotation_info_0 =
{
  -1,
  (gchar *) "org.freedesktop.DBus.Property.EmitsChangedSignal",
  (gchar *) "const",
  NULL
};

static const GDBusAnnotationInfo * const _logind_session_property_scope_annotation_info_pointers[] =
{
  &_logind_session_property_scope_annotation_info_0,
  NULL
};

static const _ExtendedGDBusPropertyInfo _logind_session_property_info_scope =
{
  {
    -1,
    (gchar *) "Scope",
    (gchar *) "s",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    (GDBusAnnotationInfo **) &_logind_session_property_scope_annotation_info_pointers
  },
  "scope",
  FALSE
};

static const GDBusAnnotationInfo _logind_session_property_leader_annotation_info_0 =
{
  -1,
  (gchar *) "org.freedesktop.DBus.Property.EmitsChangedSignal",
  (gchar *) "const",
  NULL
};

static const GDBusAnnotationInfo * const _logind_session_property_leader_annotation_info_pointers[] =
{
  &_logind_session_property_leader_annotation_info_0,
  NULL
};

static const _ExtendedGDBusPropertyInfo _logind_session_property_info_leader =
{
  {
    -1,
    (gchar *) "Leader",
    (gchar *) "u",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    (GDBusAnnotationInfo **) &_logind_session_property_leader_annotation_info_pointers
  },
  "leader",
  FALSE
};

static const GDBusAnnotationInfo _logind_session_property_audit_annotation_info_0 =
{
  -1,
  (gchar *) "org.freedesktop.DBus.Property.EmitsChangedSignal",
  (gchar *) "const",
  NULL
};

static const GDBusAnnotationInfo * const _logind_session_property_audit_annotation_info_pointers[] =
{
  &_logind_session_property_audit_annotation_info_0,
  NULL
};

static const _ExtendedGDBusPropertyInfo _logind_session_property_info_audit =
{
  {
    -1,
    (gchar *) "Audit",
    (gchar *) "u",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    (GDBusAnnotationInfo **) &_logind_session_property_audit_annotation_info_pointers
  },
  "audit",
  FALSE
};

static const GDBusAnnotationInfo _logind_session_property_type__annotation_info_0 =
{
  -1,
  (gchar *) "org.freedesktop.DBus.Property.EmitsChangedSignal",
  (gchar *) "const",
  NULL
};

static const GDBusAnnotationInfo * const _logind_session_property_type__annotation_info_pointers[] =
{
  &_logind_session_property_type__annotation_info_0,
  NULL
};

static const _ExtendedGDBusPropertyInfo _logind_session_property_info_type_ =
{
  {
    -1,
    (gchar *) "Type",
    (gchar *) "s",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    (GDBusAnnotationInfo **) &_logind_session_property_type__annotation_info_pointers
  },
  "type",
  FALSE
};

static const GDBusAnnotationInfo _logind_session_property_class_annotation_info_0 =
{
  -1,
  (gchar *) "org.freedesktop.DBus.Property.EmitsChangedSignal",
  (gchar *) "const",
  NULL
};

static const GDBusAnnotationInfo * const _logind_session_property_class_annotation_info_pointers[] =
{
  &_logind_session_property_class_annotation_info_0,
  NULL
};

static const _ExtendedGDBusPropertyInfo _logind_session_property_info_class =
{
  {
    -1,
    (gchar *) "Class",
    (gchar *) "s",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    (GDBusAnnotationInfo **) &_logind_session_property_class_annotation_info_pointers
  },
  "class",
  FALSE
};

static const _ExtendedGDBusPropertyInfo _logind_session_property_info_active =
{
  {
    -1,
    (gchar *) "Active",
    (gchar *) "b",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "active",
  FALSE
};

static const GDBusAnnotationInfo _logind_session_property_state_annotation_info_0 =
{
  -1,
  (gchar *) "org.freedesktop.DBus.Property.EmitsChangedSignal",
  (gchar *) "false",
  NULL
};

static const GDBusAnnotationInfo * const _logind_session_property_state_annotation_info_pointers[] =
{
  &_logind_session_property_state_annotation_info_0,
  NULL
};

static const _ExtendedGDBusPropertyInfo _logind_session_property_info_state =
{
  {
    -1,
    (gchar *) "State",
    (gchar *) "s",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    (GDBusAnnotationInfo **) &_logind_session_property_state_annotation_info_pointers
  },
  "state",
  FALSE
};

static const _ExtendedGDBusPropertyInfo _logind_session_property_info_idle_hint =
{
  {
    -1,
    (gchar *) "IdleHint",
    (gchar *) "b",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "idle-hint",
  FALSE
};

static const _ExtendedGDBusPropertyInfo _logind_session_property_info_idle_since_hint =
{
  {
    -1,
    (gchar *) "IdleSinceHint",
    (gchar *) "t",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "idle-since-hint",
  FALSE
};

static const _ExtendedGDBusPropertyInfo _logind_session_property_info_idle_since_hint_monotonic =
{
  {
    -1,
    (gchar *) "IdleSinceHintMonotonic",
    (gchar *) "t",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "idle-since-hint-monotonic",
  FALSE
};

static const _ExtendedGDBusPropertyInfo _logind_session_property_info_locked_hint =
{
  {
    -1,
    (gchar *) "LockedHint",
    (gchar *) "b",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "locked-hint",
  FALSE
};

static const _ExtendedGDBusPropertyInfo * const _logind_session_property_info_pointers[] =
{
  &_logind_session_property_info_id,
  &_logind_session_property_info_user,
  &_logind_session_property_info_name,
  &_logind_session_property_info_timestamp,
  &_logind_session_property_info_timestamp_monotonic,
  &_logind_session_property_info_vtnr,
  &_logind_session_property_info_seat,
  &_logind_session_property_info_tty,
  &_logind_session_property_info_display,
  &_logind_session_property_info_remote,
  &_logind_session_property_info_remote_host,
  &_logind_session_property_info_remote_user,
  &_logind_session_property_info_service,
  &_logind_session_property_info_desktop,
  &_logind_session_property_info_scope,
  &_logind_session_property_info_leader,
  &_logind_session_property_info_audit,
  &_logind_session_property_info_type_,
  &_logind_session_property_info_class,
  &_logind_session_property_info_active,
  &_logind_session_property_info_state,
  &_logind_session_property_info_idle_hint,
  &_logind_session_property_info_idle_since_hint,
  &_logind_session_property_info_idle_since_hint_monotonic,
  &_logind_session_property_info_locked_hint,
  NULL
};

static const _ExtendedGDBusInterfaceInfo _logind_session_interface_info =
{
  {
    -1,
    (gchar *) "org.freedesktop.login1.Session",
    (GDBusMethodInfo **) &_logind_session_method_info_pointers,
    (GDBusSignalInfo **) &_logind_session_signal_info_pointers,
    (GDBusPropertyInfo **) &_logind_session_property_info_pointers,
    NULL
  },
  "session",
};


/**
 * logind_session_interface_info:
 *
 * Gets a machine-readable description of the <link linkend="gdbus-interface-org-freedesktop-login1-Session.top_of_page">org.freedesktop.login1.Session</link> D-Bus interface.
 *
 * Returns: (transfer none): A #GDBusInterfaceInfo. Do not free.
 */
GDBusInterfaceInfo *
logind_session_interface_info (void)
{
  return (GDBusInterfaceInfo *) &_logind_session_interface_info.parent_struct;
}

/**
 * logind_session_override_properties:
 * @klass: The class structure for a #GObject derived class.
 * @property_id_begin: The property id to assign to the first overridden property.
 *
 * Overrides all #GObject properties in the #LogindSession interface for a concrete class.
 * The properties are overridden in the order they are defined.
 *
 * Returns: The last property id.
 */
guint
logind_session_override_properties (GObjectClass *klass, guint property_id_begin)
{
  g_object_class_override_property (klass, property_id_begin++, "id");
  g_object_class_override_property (klass, property_id_begin++, "user");
  g_object_class_override_property (klass, property_id_begin++, "name");
  g_object_class_override_property (klass, property_id_begin++, "timestamp");
  g_object_class_override_property (klass, property_id_begin++, "timestamp-monotonic");
  g_object_class_override_property (klass, property_id_begin++, "vtnr");
  g_object_class_override_property (klass, property_id_begin++, "seat");
  g_object_class_override_property (klass, property_id_begin++, "tty");
  g_object_class_override_property (klass, property_id_begin++, "display");
  g_object_class_override_property (klass, property_id_begin++, "remote");
  g_object_class_override_property (klass, property_id_begin++, "remote-host");
  g_object_class_override_property (klass, property_id_begin++, "remote-user");
  g_object_class_override_property (klass, property_id_begin++, "service");
  g_object_class_override_property (klass, property_id_begin++, "desktop");
  g_object_class_override_property (klass, property_id_begin++, "scope");
  g_object_class_override_property (klass, property_id_begin++, "leader");
  g_object_class_override_property (klass, property_id_begin++, "audit");
  g_object_class_override_property (klass, property_id_begin++, "type");
  g_object_class_override_property (klass, property_id_begin++, "class");
  g_object_class_override_property (klass, property_id_begin++, "active");
  g_object_class_override_property (klass, property_id_begin++, "state");
  g_object_class_override_property (klass, property_id_begin++, "idle-hint");
  g_object_class_override_property (klass, property_id_begin++, "idle-since-hint");
  g_object_class_override_property (klass, property_id_begin++, "idle-since-hint-monotonic");
  g_object_class_override_property (klass, property_id_begin++, "locked-hint");
  return property_id_begin - 1;
}



/**
 * LogindSession:
 *
 * Abstract interface type for the D-Bus interface <link linkend="gdbus-interface-org-freedesktop-login1-Session.top_of_page">org.freedesktop.login1.Session</link>.
 */

/**
 * LogindSessionIface:
 * @parent_iface: The parent interface.
 * @handle_activate: Handler for the #LogindSession::handle-activate signal.
 * @handle_kill: Handler for the #LogindSession::handle-kill signal.
 * @handle_lock: Handler for the #LogindSession::handle-lock signal.
 * @handle_pause_device_complete: Handler for the #LogindSession::handle-pause-device-complete signal.
 * @handle_release_control: Handler for the #LogindSession::handle-release-control signal.
 * @handle_release_device: Handler for the #LogindSession::handle-release-device signal.
 * @handle_set_idle_hint: Handler for the #LogindSession::handle-set-idle-hint signal.
 * @handle_set_locked_hint: Handler for the #LogindSession::handle-set-locked-hint signal.
 * @handle_take_control: Handler for the #LogindSession::handle-take-control signal.
 * @handle_take_device: Handler for the #LogindSession::handle-take-device signal.
 * @handle_terminate: Handler for the #LogindSession::handle-terminate signal.
 * @handle_unlock: Handler for the #LogindSession::handle-unlock signal.
 * @get_active: Getter for the #LogindSession:active property.
 * @get_audit: Getter for the #LogindSession:audit property.
 * @get_class: Getter for the #LogindSession:class property.
 * @get_desktop: Getter for the #LogindSession:desktop property.
 * @get_display: Getter for the #LogindSession:display property.
 * @get_id: Getter for the #LogindSession:id property.
 * @get_idle_hint: Getter for the #LogindSession:idle-hint property.
 * @get_idle_since_hint: Getter for the #LogindSession:idle-since-hint property.
 * @get_idle_since_hint_monotonic: Getter for the #LogindSession:idle-since-hint-monotonic property.
 * @get_leader: Getter for the #LogindSession:leader property.
 * @get_locked_hint: Getter for the #LogindSession:locked-hint property.
 * @get_name: Getter for the #LogindSession:name property.
 * @get_remote: Getter for the #LogindSession:remote property.
 * @get_remote_host: Getter for the #LogindSession:remote-host property.
 * @get_remote_user: Getter for the #LogindSession:remote-user property.
 * @get_scope: Getter for the #LogindSession:scope property.
 * @get_seat: Getter for the #LogindSession:seat property.
 * @get_service: Getter for the #LogindSession:service property.
 * @get_state: Getter for the #LogindSession:state property.
 * @get_timestamp: Getter for the #LogindSession:timestamp property.
 * @get_timestamp_monotonic: Getter for the #LogindSession:timestamp-monotonic property.
 * @get_tty: Getter for the #LogindSession:tty property.
 * @get_type_: Getter for the #LogindSession:type property.
 * @get_user: Getter for the #LogindSession:user property.
 * @get_vtnr: Getter for the #LogindSession:vtnr property.
 * @lock: Handler for the #LogindSession::lock signal.
 * @pause_device: Handler for the #LogindSession::pause-device signal.
 * @resume_device: Handler for the #LogindSession::resume-device signal.
 * @unlock: Handler for the #LogindSession::unlock signal.
 *
 * Virtual table for the D-Bus interface <link linkend="gdbus-interface-org-freedesktop-login1-Session.top_of_page">org.freedesktop.login1.Session</link>.
 */

typedef LogindSessionIface LogindSessionInterface;
G_DEFINE_INTERFACE (LogindSession, logind_session, G_TYPE_OBJECT)

static void
logind_session_default_init (LogindSessionIface *iface)
{
  /* GObject signals for incoming D-Bus method calls: */
  /**
   * LogindSession::handle-terminate:
   * @object: A #LogindSession.
   * @invocation: A #GDBusMethodInvocation.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-freedesktop-login1-Session.Terminate">Terminate()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call logind_session_complete_terminate() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-terminate",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (LogindSessionIface, handle_terminate),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    1,
    G_TYPE_DBUS_METHOD_INVOCATION);

  /**
   * LogindSession::handle-activate:
   * @object: A #LogindSession.
   * @invocation: A #GDBusMethodInvocation.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-freedesktop-login1-Session.Activate">Activate()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call logind_session_complete_activate() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-activate",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (LogindSessionIface, handle_activate),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    1,
    G_TYPE_DBUS_METHOD_INVOCATION);

  /**
   * LogindSession::handle-lock:
   * @object: A #LogindSession.
   * @invocation: A #GDBusMethodInvocation.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-freedesktop-login1-Session.Lock">Lock()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call logind_session_complete_lock() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-lock",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (LogindSessionIface, handle_lock),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    1,
    G_TYPE_DBUS_METHOD_INVOCATION);

  /**
   * LogindSession::handle-unlock:
   * @object: A #LogindSession.
   * @invocation: A #GDBusMethodInvocation.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-freedesktop-login1-Session.Unlock">Unlock()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call logind_session_complete_unlock() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-unlock",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (LogindSessionIface, handle_unlock),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    1,
    G_TYPE_DBUS_METHOD_INVOCATION);

  /**
   * LogindSession::handle-set-idle-hint:
   * @object: A #LogindSession.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_unnamed_arg0: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-freedesktop-login1-Session.SetIdleHint">SetIdleHint()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call logind_session_complete_set_idle_hint() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-set-idle-hint",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (LogindSessionIface, handle_set_idle_hint),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    2,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_BOOLEAN);

  /**
   * LogindSession::handle-set-locked-hint:
   * @object: A #LogindSession.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_unnamed_arg0: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-freedesktop-login1-Session.SetLockedHint">SetLockedHint()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call logind_session_complete_set_locked_hint() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-set-locked-hint",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (LogindSessionIface, handle_set_locked_hint),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    2,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_BOOLEAN);

  /**
   * LogindSession::handle-kill:
   * @object: A #LogindSession.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_unnamed_arg0: Argument passed by remote caller.
   * @arg_unnamed_arg1: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-freedesktop-login1-Session.Kill">Kill()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call logind_session_complete_kill() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-kill",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (LogindSessionIface, handle_kill),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    3,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_STRING, G_TYPE_INT);

  /**
   * LogindSession::handle-take-control:
   * @object: A #LogindSession.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_unnamed_arg0: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-freedesktop-login1-Session.TakeControl">TakeControl()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call logind_session_complete_take_control() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-take-control",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (LogindSessionIface, handle_take_control),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    2,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_BOOLEAN);

  /**
   * LogindSession::handle-release-control:
   * @object: A #LogindSession.
   * @invocation: A #GDBusMethodInvocation.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-freedesktop-login1-Session.ReleaseControl">ReleaseControl()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call logind_session_complete_release_control() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-release-control",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (LogindSessionIface, handle_release_control),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    1,
    G_TYPE_DBUS_METHOD_INVOCATION);

  /**
   * LogindSession::handle-take-device:
   * @object: A #LogindSession.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_unnamed_arg0: Argument passed by remote caller.
   * @arg_unnamed_arg1: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-freedesktop-login1-Session.TakeDevice">TakeDevice()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call logind_session_complete_take_device() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-take-device",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (LogindSessionIface, handle_take_device),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    3,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_UINT, G_TYPE_UINT);

  /**
   * LogindSession::handle-release-device:
   * @object: A #LogindSession.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_unnamed_arg0: Argument passed by remote caller.
   * @arg_unnamed_arg1: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-freedesktop-login1-Session.ReleaseDevice">ReleaseDevice()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call logind_session_complete_release_device() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-release-device",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (LogindSessionIface, handle_release_device),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    3,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_UINT, G_TYPE_UINT);

  /**
   * LogindSession::handle-pause-device-complete:
   * @object: A #LogindSession.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_unnamed_arg0: Argument passed by remote caller.
   * @arg_unnamed_arg1: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-freedesktop-login1-Session.PauseDeviceComplete">PauseDeviceComplete()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call logind_session_complete_pause_device_complete() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-pause-device-complete",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (LogindSessionIface, handle_pause_device_complete),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    3,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_UINT, G_TYPE_UINT);

  /* GObject signals for received D-Bus signals: */
  /**
   * LogindSession::pause-device:
   * @object: A #LogindSession.
   * @arg_unnamed_arg0: Argument.
   * @arg_unnamed_arg1: Argument.
   * @arg_unnamed_arg2: Argument.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-freedesktop-login1-Session.PauseDevice">"PauseDevice"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  g_signal_new ("pause-device",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (LogindSessionIface, pause_device),
    NULL,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_NONE,
    3, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_STRING);

  /**
   * LogindSession::resume-device:
   * @object: A #LogindSession.
   * @arg_unnamed_arg0: Argument.
   * @arg_unnamed_arg1: Argument.
   * @arg_unnamed_arg2: Argument.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-freedesktop-login1-Session.ResumeDevice">"ResumeDevice"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  g_signal_new ("resume-device",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (LogindSessionIface, resume_device),
    NULL,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_NONE,
    3, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_VARIANT);

  /**
   * LogindSession::lock:
   * @object: A #LogindSession.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-freedesktop-login1-Session.Lock">"Lock"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  g_signal_new ("lock",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (LogindSessionIface, lock),
    NULL,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_NONE,
    0);

  /**
   * LogindSession::unlock:
   * @object: A #LogindSession.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-freedesktop-login1-Session.Unlock">"Unlock"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  g_signal_new ("unlock",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (LogindSessionIface, unlock),
    NULL,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_NONE,
    0);

  /* GObject properties for D-Bus properties: */
  /**
   * LogindSession:id:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-login1-Session.Id">"Id"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_string ("id", "Id", "Id", NULL, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * LogindSession:user:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-login1-Session.User">"User"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_variant ("user", "User", "User", G_VARIANT_TYPE ("(uo)"), NULL, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * LogindSession:name:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-login1-Session.Name">"Name"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_string ("name", "Name", "Name", NULL, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * LogindSession:timestamp:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-login1-Session.Timestamp">"Timestamp"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_uint64 ("timestamp", "Timestamp", "Timestamp", 0, G_MAXUINT64, 0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * LogindSession:timestamp-monotonic:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-login1-Session.TimestampMonotonic">"TimestampMonotonic"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_uint64 ("timestamp-monotonic", "TimestampMonotonic", "TimestampMonotonic", 0, G_MAXUINT64, 0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * LogindSession:vtnr:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-login1-Session.VTNr">"VTNr"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_uint ("vtnr", "VTNr", "VTNr", 0, G_MAXUINT32, 0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * LogindSession:seat:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-login1-Session.Seat">"Seat"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_variant ("seat", "Seat", "Seat", G_VARIANT_TYPE ("(so)"), NULL, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * LogindSession:tty:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-login1-Session.TTY">"TTY"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_string ("tty", "TTY", "TTY", NULL, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * LogindSession:display:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-login1-Session.Display">"Display"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_string ("display", "Display", "Display", NULL, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * LogindSession:remote:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-login1-Session.Remote">"Remote"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_boolean ("remote", "Remote", "Remote", FALSE, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * LogindSession:remote-host:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-login1-Session.RemoteHost">"RemoteHost"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_string ("remote-host", "RemoteHost", "RemoteHost", NULL, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * LogindSession:remote-user:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-login1-Session.RemoteUser">"RemoteUser"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_string ("remote-user", "RemoteUser", "RemoteUser", NULL, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * LogindSession:service:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-login1-Session.Service">"Service"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_string ("service", "Service", "Service", NULL, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * LogindSession:desktop:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-login1-Session.Desktop">"Desktop"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_string ("desktop", "Desktop", "Desktop", NULL, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * LogindSession:scope:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-login1-Session.Scope">"Scope"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_string ("scope", "Scope", "Scope", NULL, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * LogindSession:leader:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-login1-Session.Leader">"Leader"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_uint ("leader", "Leader", "Leader", 0, G_MAXUINT32, 0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * LogindSession:audit:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-login1-Session.Audit">"Audit"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_uint ("audit", "Audit", "Audit", 0, G_MAXUINT32, 0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * LogindSession:type:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-login1-Session.Type">"Type"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_string ("type", "Type", "Type", NULL, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * LogindSession:class:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-login1-Session.Class">"Class"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_string ("class", "Class", "Class", NULL, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * LogindSession:active:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-login1-Session.Active">"Active"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_boolean ("active", "Active", "Active", FALSE, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * LogindSession:state:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-login1-Session.State">"State"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_string ("state", "State", "State", NULL, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * LogindSession:idle-hint:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-login1-Session.IdleHint">"IdleHint"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_boolean ("idle-hint", "IdleHint", "IdleHint", FALSE, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * LogindSession:idle-since-hint:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-login1-Session.IdleSinceHint">"IdleSinceHint"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_uint64 ("idle-since-hint", "IdleSinceHint", "IdleSinceHint", 0, G_MAXUINT64, 0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * LogindSession:idle-since-hint-monotonic:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-login1-Session.IdleSinceHintMonotonic">"IdleSinceHintMonotonic"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_uint64 ("idle-since-hint-monotonic", "IdleSinceHintMonotonic", "IdleSinceHintMonotonic", 0, G_MAXUINT64, 0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * LogindSession:locked-hint:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-login1-Session.LockedHint">"LockedHint"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_boolean ("locked-hint", "LockedHint", "LockedHint", FALSE, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
}

/**
 * logind_session_get_id: (skip)
 * @object: A #LogindSession.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-login1-Session.Id">"Id"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * <warning>The returned value is only valid until the property changes so on the client-side it is only safe to use this function on the thread where @object was constructed. Use logind_session_dup_id() if on another thread.</warning>
 *
 * Returns: (transfer none): The property value or %NULL if the property is not set. Do not free the returned value, it belongs to @object.
 */
const gchar *
logind_session_get_id (LogindSession *object)
{
  return LOGIND_SESSION_GET_IFACE (object)->get_id (object);
}

/**
 * logind_session_dup_id: (skip)
 * @object: A #LogindSession.
 *
 * Gets a copy of the <link linkend="gdbus-property-org-freedesktop-login1-Session.Id">"Id"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: (transfer full): The property value or %NULL if the property is not set. The returned value should be freed with g_free().
 */
gchar *
logind_session_dup_id (LogindSession *object)
{
  gchar *value;
  g_object_get (G_OBJECT (object), "id", &value, NULL);
  return value;
}

/**
 * logind_session_set_id: (skip)
 * @object: A #LogindSession.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-login1-Session.Id">"Id"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
logind_session_set_id (LogindSession *object, const gchar *value)
{
  g_object_set (G_OBJECT (object), "id", value, NULL);
}

/**
 * logind_session_get_user: (skip)
 * @object: A #LogindSession.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-login1-Session.User">"User"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * <warning>The returned value is only valid until the property changes so on the client-side it is only safe to use this function on the thread where @object was constructed. Use logind_session_dup_user() if on another thread.</warning>
 *
 * Returns: (transfer none): The property value or %NULL if the property is not set. Do not free the returned value, it belongs to @object.
 */
GVariant *
logind_session_get_user (LogindSession *object)
{
  return LOGIND_SESSION_GET_IFACE (object)->get_user (object);
}

/**
 * logind_session_dup_user: (skip)
 * @object: A #LogindSession.
 *
 * Gets a copy of the <link linkend="gdbus-property-org-freedesktop-login1-Session.User">"User"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: (transfer full): The property value or %NULL if the property is not set. The returned value should be freed with g_variant_unref().
 */
GVariant *
logind_session_dup_user (LogindSession *object)
{
  GVariant *value;
  g_object_get (G_OBJECT (object), "user", &value, NULL);
  return value;
}

/**
 * logind_session_set_user: (skip)
 * @object: A #LogindSession.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-login1-Session.User">"User"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
logind_session_set_user (LogindSession *object, GVariant *value)
{
  g_object_set (G_OBJECT (object), "user", value, NULL);
}

/**
 * logind_session_get_name: (skip)
 * @object: A #LogindSession.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-login1-Session.Name">"Name"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * <warning>The returned value is only valid until the property changes so on the client-side it is only safe to use this function on the thread where @object was constructed. Use logind_session_dup_name() if on another thread.</warning>
 *
 * Returns: (transfer none): The property value or %NULL if the property is not set. Do not free the returned value, it belongs to @object.
 */
const gchar *
logind_session_get_name (LogindSession *object)
{
  return LOGIND_SESSION_GET_IFACE (object)->get_name (object);
}

/**
 * logind_session_dup_name: (skip)
 * @object: A #LogindSession.
 *
 * Gets a copy of the <link linkend="gdbus-property-org-freedesktop-login1-Session.Name">"Name"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: (transfer full): The property value or %NULL if the property is not set. The returned value should be freed with g_free().
 */
gchar *
logind_session_dup_name (LogindSession *object)
{
  gchar *value;
  g_object_get (G_OBJECT (object), "name", &value, NULL);
  return value;
}

/**
 * logind_session_set_name: (skip)
 * @object: A #LogindSession.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-login1-Session.Name">"Name"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
logind_session_set_name (LogindSession *object, const gchar *value)
{
  g_object_set (G_OBJECT (object), "name", value, NULL);
}

/**
 * logind_session_get_timestamp: (skip)
 * @object: A #LogindSession.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-login1-Session.Timestamp">"Timestamp"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
guint64 
logind_session_get_timestamp (LogindSession *object)
{
  return LOGIND_SESSION_GET_IFACE (object)->get_timestamp (object);
}

/**
 * logind_session_set_timestamp: (skip)
 * @object: A #LogindSession.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-login1-Session.Timestamp">"Timestamp"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
logind_session_set_timestamp (LogindSession *object, guint64 value)
{
  g_object_set (G_OBJECT (object), "timestamp", value, NULL);
}

/**
 * logind_session_get_timestamp_monotonic: (skip)
 * @object: A #LogindSession.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-login1-Session.TimestampMonotonic">"TimestampMonotonic"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
guint64 
logind_session_get_timestamp_monotonic (LogindSession *object)
{
  return LOGIND_SESSION_GET_IFACE (object)->get_timestamp_monotonic (object);
}

/**
 * logind_session_set_timestamp_monotonic: (skip)
 * @object: A #LogindSession.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-login1-Session.TimestampMonotonic">"TimestampMonotonic"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
logind_session_set_timestamp_monotonic (LogindSession *object, guint64 value)
{
  g_object_set (G_OBJECT (object), "timestamp-monotonic", value, NULL);
}

/**
 * logind_session_get_vtnr: (skip)
 * @object: A #LogindSession.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-login1-Session.VTNr">"VTNr"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
guint 
logind_session_get_vtnr (LogindSession *object)
{
  return LOGIND_SESSION_GET_IFACE (object)->get_vtnr (object);
}

/**
 * logind_session_set_vtnr: (skip)
 * @object: A #LogindSession.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-login1-Session.VTNr">"VTNr"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
logind_session_set_vtnr (LogindSession *object, guint value)
{
  g_object_set (G_OBJECT (object), "vtnr", value, NULL);
}

/**
 * logind_session_get_seat: (skip)
 * @object: A #LogindSession.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-login1-Session.Seat">"Seat"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * <warning>The returned value is only valid until the property changes so on the client-side it is only safe to use this function on the thread where @object was constructed. Use logind_session_dup_seat() if on another thread.</warning>
 *
 * Returns: (transfer none): The property value or %NULL if the property is not set. Do not free the returned value, it belongs to @object.
 */
GVariant *
logind_session_get_seat (LogindSession *object)
{
  return LOGIND_SESSION_GET_IFACE (object)->get_seat (object);
}

/**
 * logind_session_dup_seat: (skip)
 * @object: A #LogindSession.
 *
 * Gets a copy of the <link linkend="gdbus-property-org-freedesktop-login1-Session.Seat">"Seat"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: (transfer full): The property value or %NULL if the property is not set. The returned value should be freed with g_variant_unref().
 */
GVariant *
logind_session_dup_seat (LogindSession *object)
{
  GVariant *value;
  g_object_get (G_OBJECT (object), "seat", &value, NULL);
  return value;
}

/**
 * logind_session_set_seat: (skip)
 * @object: A #LogindSession.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-login1-Session.Seat">"Seat"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
logind_session_set_seat (LogindSession *object, GVariant *value)
{
  g_object_set (G_OBJECT (object), "seat", value, NULL);
}

/**
 * logind_session_get_tty: (skip)
 * @object: A #LogindSession.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-login1-Session.TTY">"TTY"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * <warning>The returned value is only valid until the property changes so on the client-side it is only safe to use this function on the thread where @object was constructed. Use logind_session_dup_tty() if on another thread.</warning>
 *
 * Returns: (transfer none): The property value or %NULL if the property is not set. Do not free the returned value, it belongs to @object.
 */
const gchar *
logind_session_get_tty (LogindSession *object)
{
  return LOGIND_SESSION_GET_IFACE (object)->get_tty (object);
}

/**
 * logind_session_dup_tty: (skip)
 * @object: A #LogindSession.
 *
 * Gets a copy of the <link linkend="gdbus-property-org-freedesktop-login1-Session.TTY">"TTY"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: (transfer full): The property value or %NULL if the property is not set. The returned value should be freed with g_free().
 */
gchar *
logind_session_dup_tty (LogindSession *object)
{
  gchar *value;
  g_object_get (G_OBJECT (object), "tty", &value, NULL);
  return value;
}

/**
 * logind_session_set_tty: (skip)
 * @object: A #LogindSession.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-login1-Session.TTY">"TTY"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
logind_session_set_tty (LogindSession *object, const gchar *value)
{
  g_object_set (G_OBJECT (object), "tty", value, NULL);
}

/**
 * logind_session_get_display: (skip)
 * @object: A #LogindSession.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-login1-Session.Display">"Display"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * <warning>The returned value is only valid until the property changes so on the client-side it is only safe to use this function on the thread where @object was constructed. Use logind_session_dup_display() if on another thread.</warning>
 *
 * Returns: (transfer none): The property value or %NULL if the property is not set. Do not free the returned value, it belongs to @object.
 */
const gchar *
logind_session_get_display (LogindSession *object)
{
  return LOGIND_SESSION_GET_IFACE (object)->get_display (object);
}

/**
 * logind_session_dup_display: (skip)
 * @object: A #LogindSession.
 *
 * Gets a copy of the <link linkend="gdbus-property-org-freedesktop-login1-Session.Display">"Display"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: (transfer full): The property value or %NULL if the property is not set. The returned value should be freed with g_free().
 */
gchar *
logind_session_dup_display (LogindSession *object)
{
  gchar *value;
  g_object_get (G_OBJECT (object), "display", &value, NULL);
  return value;
}

/**
 * logind_session_set_display: (skip)
 * @object: A #LogindSession.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-login1-Session.Display">"Display"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
logind_session_set_display (LogindSession *object, const gchar *value)
{
  g_object_set (G_OBJECT (object), "display", value, NULL);
}

/**
 * logind_session_get_remote: (skip)
 * @object: A #LogindSession.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-login1-Session.Remote">"Remote"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
gboolean 
logind_session_get_remote (LogindSession *object)
{
  return LOGIND_SESSION_GET_IFACE (object)->get_remote (object);
}

/**
 * logind_session_set_remote: (skip)
 * @object: A #LogindSession.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-login1-Session.Remote">"Remote"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
logind_session_set_remote (LogindSession *object, gboolean value)
{
  g_object_set (G_OBJECT (object), "remote", value, NULL);
}

/**
 * logind_session_get_remote_host: (skip)
 * @object: A #LogindSession.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-login1-Session.RemoteHost">"RemoteHost"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * <warning>The returned value is only valid until the property changes so on the client-side it is only safe to use this function on the thread where @object was constructed. Use logind_session_dup_remote_host() if on another thread.</warning>
 *
 * Returns: (transfer none): The property value or %NULL if the property is not set. Do not free the returned value, it belongs to @object.
 */
const gchar *
logind_session_get_remote_host (LogindSession *object)
{
  return LOGIND_SESSION_GET_IFACE (object)->get_remote_host (object);
}

/**
 * logind_session_dup_remote_host: (skip)
 * @object: A #LogindSession.
 *
 * Gets a copy of the <link linkend="gdbus-property-org-freedesktop-login1-Session.RemoteHost">"RemoteHost"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: (transfer full): The property value or %NULL if the property is not set. The returned value should be freed with g_free().
 */
gchar *
logind_session_dup_remote_host (LogindSession *object)
{
  gchar *value;
  g_object_get (G_OBJECT (object), "remote-host", &value, NULL);
  return value;
}

/**
 * logind_session_set_remote_host: (skip)
 * @object: A #LogindSession.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-login1-Session.RemoteHost">"RemoteHost"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
logind_session_set_remote_host (LogindSession *object, const gchar *value)
{
  g_object_set (G_OBJECT (object), "remote-host", value, NULL);
}

/**
 * logind_session_get_remote_user: (skip)
 * @object: A #LogindSession.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-login1-Session.RemoteUser">"RemoteUser"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * <warning>The returned value is only valid until the property changes so on the client-side it is only safe to use this function on the thread where @object was constructed. Use logind_session_dup_remote_user() if on another thread.</warning>
 *
 * Returns: (transfer none): The property value or %NULL if the property is not set. Do not free the returned value, it belongs to @object.
 */
const gchar *
logind_session_get_remote_user (LogindSession *object)
{
  return LOGIND_SESSION_GET_IFACE (object)->get_remote_user (object);
}

/**
 * logind_session_dup_remote_user: (skip)
 * @object: A #LogindSession.
 *
 * Gets a copy of the <link linkend="gdbus-property-org-freedesktop-login1-Session.RemoteUser">"RemoteUser"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: (transfer full): The property value or %NULL if the property is not set. The returned value should be freed with g_free().
 */
gchar *
logind_session_dup_remote_user (LogindSession *object)
{
  gchar *value;
  g_object_get (G_OBJECT (object), "remote-user", &value, NULL);
  return value;
}

/**
 * logind_session_set_remote_user: (skip)
 * @object: A #LogindSession.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-login1-Session.RemoteUser">"RemoteUser"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
logind_session_set_remote_user (LogindSession *object, const gchar *value)
{
  g_object_set (G_OBJECT (object), "remote-user", value, NULL);
}

/**
 * logind_session_get_service: (skip)
 * @object: A #LogindSession.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-login1-Session.Service">"Service"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * <warning>The returned value is only valid until the property changes so on the client-side it is only safe to use this function on the thread where @object was constructed. Use logind_session_dup_service() if on another thread.</warning>
 *
 * Returns: (transfer none): The property value or %NULL if the property is not set. Do not free the returned value, it belongs to @object.
 */
const gchar *
logind_session_get_service (LogindSession *object)
{
  return LOGIND_SESSION_GET_IFACE (object)->get_service (object);
}

/**
 * logind_session_dup_service: (skip)
 * @object: A #LogindSession.
 *
 * Gets a copy of the <link linkend="gdbus-property-org-freedesktop-login1-Session.Service">"Service"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: (transfer full): The property value or %NULL if the property is not set. The returned value should be freed with g_free().
 */
gchar *
logind_session_dup_service (LogindSession *object)
{
  gchar *value;
  g_object_get (G_OBJECT (object), "service", &value, NULL);
  return value;
}

/**
 * logind_session_set_service: (skip)
 * @object: A #LogindSession.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-login1-Session.Service">"Service"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
logind_session_set_service (LogindSession *object, const gchar *value)
{
  g_object_set (G_OBJECT (object), "service", value, NULL);
}

/**
 * logind_session_get_desktop: (skip)
 * @object: A #LogindSession.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-login1-Session.Desktop">"Desktop"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * <warning>The returned value is only valid until the property changes so on the client-side it is only safe to use this function on the thread where @object was constructed. Use logind_session_dup_desktop() if on another thread.</warning>
 *
 * Returns: (transfer none): The property value or %NULL if the property is not set. Do not free the returned value, it belongs to @object.
 */
const gchar *
logind_session_get_desktop (LogindSession *object)
{
  return LOGIND_SESSION_GET_IFACE (object)->get_desktop (object);
}

/**
 * logind_session_dup_desktop: (skip)
 * @object: A #LogindSession.
 *
 * Gets a copy of the <link linkend="gdbus-property-org-freedesktop-login1-Session.Desktop">"Desktop"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: (transfer full): The property value or %NULL if the property is not set. The returned value should be freed with g_free().
 */
gchar *
logind_session_dup_desktop (LogindSession *object)
{
  gchar *value;
  g_object_get (G_OBJECT (object), "desktop", &value, NULL);
  return value;
}

/**
 * logind_session_set_desktop: (skip)
 * @object: A #LogindSession.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-login1-Session.Desktop">"Desktop"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
logind_session_set_desktop (LogindSession *object, const gchar *value)
{
  g_object_set (G_OBJECT (object), "desktop", value, NULL);
}

/**
 * logind_session_get_scope: (skip)
 * @object: A #LogindSession.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-login1-Session.Scope">"Scope"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * <warning>The returned value is only valid until the property changes so on the client-side it is only safe to use this function on the thread where @object was constructed. Use logind_session_dup_scope() if on another thread.</warning>
 *
 * Returns: (transfer none): The property value or %NULL if the property is not set. Do not free the returned value, it belongs to @object.
 */
const gchar *
logind_session_get_scope (LogindSession *object)
{
  return LOGIND_SESSION_GET_IFACE (object)->get_scope (object);
}

/**
 * logind_session_dup_scope: (skip)
 * @object: A #LogindSession.
 *
 * Gets a copy of the <link linkend="gdbus-property-org-freedesktop-login1-Session.Scope">"Scope"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: (transfer full): The property value or %NULL if the property is not set. The returned value should be freed with g_free().
 */
gchar *
logind_session_dup_scope (LogindSession *object)
{
  gchar *value;
  g_object_get (G_OBJECT (object), "scope", &value, NULL);
  return value;
}

/**
 * logind_session_set_scope: (skip)
 * @object: A #LogindSession.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-login1-Session.Scope">"Scope"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
logind_session_set_scope (LogindSession *object, const gchar *value)
{
  g_object_set (G_OBJECT (object), "scope", value, NULL);
}

/**
 * logind_session_get_leader: (skip)
 * @object: A #LogindSession.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-login1-Session.Leader">"Leader"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
guint 
logind_session_get_leader (LogindSession *object)
{
  return LOGIND_SESSION_GET_IFACE (object)->get_leader (object);
}

/**
 * logind_session_set_leader: (skip)
 * @object: A #LogindSession.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-login1-Session.Leader">"Leader"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
logind_session_set_leader (LogindSession *object, guint value)
{
  g_object_set (G_OBJECT (object), "leader", value, NULL);
}

/**
 * logind_session_get_audit: (skip)
 * @object: A #LogindSession.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-login1-Session.Audit">"Audit"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
guint 
logind_session_get_audit (LogindSession *object)
{
  return LOGIND_SESSION_GET_IFACE (object)->get_audit (object);
}

/**
 * logind_session_set_audit: (skip)
 * @object: A #LogindSession.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-login1-Session.Audit">"Audit"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
logind_session_set_audit (LogindSession *object, guint value)
{
  g_object_set (G_OBJECT (object), "audit", value, NULL);
}

/**
 * logind_session_get_type_: (skip)
 * @object: A #LogindSession.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-login1-Session.Type">"Type"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * <warning>The returned value is only valid until the property changes so on the client-side it is only safe to use this function on the thread where @object was constructed. Use logind_session_dup_type_() if on another thread.</warning>
 *
 * Returns: (transfer none): The property value or %NULL if the property is not set. Do not free the returned value, it belongs to @object.
 */
const gchar *
logind_session_get_type_ (LogindSession *object)
{
  return LOGIND_SESSION_GET_IFACE (object)->get_type_ (object);
}

/**
 * logind_session_dup_type_: (skip)
 * @object: A #LogindSession.
 *
 * Gets a copy of the <link linkend="gdbus-property-org-freedesktop-login1-Session.Type">"Type"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: (transfer full): The property value or %NULL if the property is not set. The returned value should be freed with g_free().
 */
gchar *
logind_session_dup_type_ (LogindSession *object)
{
  gchar *value;
  g_object_get (G_OBJECT (object), "type", &value, NULL);
  return value;
}

/**
 * logind_session_set_type_: (skip)
 * @object: A #LogindSession.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-login1-Session.Type">"Type"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
logind_session_set_type_ (LogindSession *object, const gchar *value)
{
  g_object_set (G_OBJECT (object), "type", value, NULL);
}

/**
 * logind_session_get_class: (skip)
 * @object: A #LogindSession.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-login1-Session.Class">"Class"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * <warning>The returned value is only valid until the property changes so on the client-side it is only safe to use this function on the thread where @object was constructed. Use logind_session_dup_class() if on another thread.</warning>
 *
 * Returns: (transfer none): The property value or %NULL if the property is not set. Do not free the returned value, it belongs to @object.
 */
const gchar *
logind_session_get_class (LogindSession *object)
{
  return LOGIND_SESSION_GET_IFACE (object)->get_class (object);
}

/**
 * logind_session_dup_class: (skip)
 * @object: A #LogindSession.
 *
 * Gets a copy of the <link linkend="gdbus-property-org-freedesktop-login1-Session.Class">"Class"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: (transfer full): The property value or %NULL if the property is not set. The returned value should be freed with g_free().
 */
gchar *
logind_session_dup_class (LogindSession *object)
{
  gchar *value;
  g_object_get (G_OBJECT (object), "class", &value, NULL);
  return value;
}

/**
 * logind_session_set_class: (skip)
 * @object: A #LogindSession.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-login1-Session.Class">"Class"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
logind_session_set_class (LogindSession *object, const gchar *value)
{
  g_object_set (G_OBJECT (object), "class", value, NULL);
}

/**
 * logind_session_get_active: (skip)
 * @object: A #LogindSession.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-login1-Session.Active">"Active"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
gboolean 
logind_session_get_active (LogindSession *object)
{
  return LOGIND_SESSION_GET_IFACE (object)->get_active (object);
}

/**
 * logind_session_set_active: (skip)
 * @object: A #LogindSession.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-login1-Session.Active">"Active"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
logind_session_set_active (LogindSession *object, gboolean value)
{
  g_object_set (G_OBJECT (object), "active", value, NULL);
}

/**
 * logind_session_get_state: (skip)
 * @object: A #LogindSession.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-login1-Session.State">"State"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * <warning>The returned value is only valid until the property changes so on the client-side it is only safe to use this function on the thread where @object was constructed. Use logind_session_dup_state() if on another thread.</warning>
 *
 * Returns: (transfer none): The property value or %NULL if the property is not set. Do not free the returned value, it belongs to @object.
 */
const gchar *
logind_session_get_state (LogindSession *object)
{
  return LOGIND_SESSION_GET_IFACE (object)->get_state (object);
}

/**
 * logind_session_dup_state: (skip)
 * @object: A #LogindSession.
 *
 * Gets a copy of the <link linkend="gdbus-property-org-freedesktop-login1-Session.State">"State"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: (transfer full): The property value or %NULL if the property is not set. The returned value should be freed with g_free().
 */
gchar *
logind_session_dup_state (LogindSession *object)
{
  gchar *value;
  g_object_get (G_OBJECT (object), "state", &value, NULL);
  return value;
}

/**
 * logind_session_set_state: (skip)
 * @object: A #LogindSession.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-login1-Session.State">"State"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
logind_session_set_state (LogindSession *object, const gchar *value)
{
  g_object_set (G_OBJECT (object), "state", value, NULL);
}

/**
 * logind_session_get_idle_hint: (skip)
 * @object: A #LogindSession.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-login1-Session.IdleHint">"IdleHint"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
gboolean 
logind_session_get_idle_hint (LogindSession *object)
{
  return LOGIND_SESSION_GET_IFACE (object)->get_idle_hint (object);
}

/**
 * logind_session_set_idle_hint: (skip)
 * @object: A #LogindSession.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-login1-Session.IdleHint">"IdleHint"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
logind_session_set_idle_hint (LogindSession *object, gboolean value)
{
  g_object_set (G_OBJECT (object), "idle-hint", value, NULL);
}

/**
 * logind_session_get_idle_since_hint: (skip)
 * @object: A #LogindSession.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-login1-Session.IdleSinceHint">"IdleSinceHint"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
guint64 
logind_session_get_idle_since_hint (LogindSession *object)
{
  return LOGIND_SESSION_GET_IFACE (object)->get_idle_since_hint (object);
}

/**
 * logind_session_set_idle_since_hint: (skip)
 * @object: A #LogindSession.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-login1-Session.IdleSinceHint">"IdleSinceHint"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
logind_session_set_idle_since_hint (LogindSession *object, guint64 value)
{
  g_object_set (G_OBJECT (object), "idle-since-hint", value, NULL);
}

/**
 * logind_session_get_idle_since_hint_monotonic: (skip)
 * @object: A #LogindSession.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-login1-Session.IdleSinceHintMonotonic">"IdleSinceHintMonotonic"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
guint64 
logind_session_get_idle_since_hint_monotonic (LogindSession *object)
{
  return LOGIND_SESSION_GET_IFACE (object)->get_idle_since_hint_monotonic (object);
}

/**
 * logind_session_set_idle_since_hint_monotonic: (skip)
 * @object: A #LogindSession.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-login1-Session.IdleSinceHintMonotonic">"IdleSinceHintMonotonic"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
logind_session_set_idle_since_hint_monotonic (LogindSession *object, guint64 value)
{
  g_object_set (G_OBJECT (object), "idle-since-hint-monotonic", value, NULL);
}

/**
 * logind_session_get_locked_hint: (skip)
 * @object: A #LogindSession.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-login1-Session.LockedHint">"LockedHint"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
gboolean 
logind_session_get_locked_hint (LogindSession *object)
{
  return LOGIND_SESSION_GET_IFACE (object)->get_locked_hint (object);
}

/**
 * logind_session_set_locked_hint: (skip)
 * @object: A #LogindSession.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-login1-Session.LockedHint">"LockedHint"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
logind_session_set_locked_hint (LogindSession *object, gboolean value)
{
  g_object_set (G_OBJECT (object), "locked-hint", value, NULL);
}

/**
 * logind_session_emit_pause_device:
 * @object: A #LogindSession.
 * @arg_unnamed_arg0: Argument to pass with the signal.
 * @arg_unnamed_arg1: Argument to pass with the signal.
 * @arg_unnamed_arg2: Argument to pass with the signal.
 *
 * Emits the <link linkend="gdbus-signal-org-freedesktop-login1-Session.PauseDevice">"PauseDevice"</link> D-Bus signal.
 */
void
logind_session_emit_pause_device (
    LogindSession *object,
    guint arg_unnamed_arg0,
    guint arg_unnamed_arg1,
    const gchar *arg_unnamed_arg2)
{
  g_signal_emit_by_name (object, "pause-device", arg_unnamed_arg0, arg_unnamed_arg1, arg_unnamed_arg2);
}

/**
 * logind_session_emit_resume_device:
 * @object: A #LogindSession.
 * @arg_unnamed_arg0: Argument to pass with the signal.
 * @arg_unnamed_arg1: Argument to pass with the signal.
 * @arg_unnamed_arg2: Argument to pass with the signal.
 *
 * Emits the <link linkend="gdbus-signal-org-freedesktop-login1-Session.ResumeDevice">"ResumeDevice"</link> D-Bus signal.
 */
void
logind_session_emit_resume_device (
    LogindSession *object,
    guint arg_unnamed_arg0,
    guint arg_unnamed_arg1,
    GVariant *arg_unnamed_arg2)
{
  g_signal_emit_by_name (object, "resume-device", arg_unnamed_arg0, arg_unnamed_arg1, arg_unnamed_arg2);
}

/**
 * logind_session_emit_lock:
 * @object: A #LogindSession.
 *
 * Emits the <link linkend="gdbus-signal-org-freedesktop-login1-Session.Lock">"Lock"</link> D-Bus signal.
 */
void
logind_session_emit_lock (
    LogindSession *object)
{
  g_signal_emit_by_name (object, "lock");
}

/**
 * logind_session_emit_unlock:
 * @object: A #LogindSession.
 *
 * Emits the <link linkend="gdbus-signal-org-freedesktop-login1-Session.Unlock">"Unlock"</link> D-Bus signal.
 */
void
logind_session_emit_unlock (
    LogindSession *object)
{
  g_signal_emit_by_name (object, "unlock");
}

/**
 * logind_session_call_terminate:
 * @proxy: A #LogindSessionProxy.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-freedesktop-login1-Session.Terminate">Terminate()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call logind_session_call_terminate_finish() to get the result of the operation.
 *
 * See logind_session_call_terminate_sync() for the synchronous, blocking version of this method.
 */
void
logind_session_call_terminate (
    LogindSession *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "Terminate",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * logind_session_call_terminate_finish:
 * @proxy: A #LogindSessionProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to logind_session_call_terminate().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with logind_session_call_terminate().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
logind_session_call_terminate_finish (
    LogindSession *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * logind_session_call_terminate_sync:
 * @proxy: A #LogindSessionProxy.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-freedesktop-login1-Session.Terminate">Terminate()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See logind_session_call_terminate() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
logind_session_call_terminate_sync (
    LogindSession *proxy,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "Terminate",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * logind_session_call_activate:
 * @proxy: A #LogindSessionProxy.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-freedesktop-login1-Session.Activate">Activate()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call logind_session_call_activate_finish() to get the result of the operation.
 *
 * See logind_session_call_activate_sync() for the synchronous, blocking version of this method.
 */
void
logind_session_call_activate (
    LogindSession *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "Activate",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * logind_session_call_activate_finish:
 * @proxy: A #LogindSessionProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to logind_session_call_activate().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with logind_session_call_activate().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
logind_session_call_activate_finish (
    LogindSession *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * logind_session_call_activate_sync:
 * @proxy: A #LogindSessionProxy.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-freedesktop-login1-Session.Activate">Activate()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See logind_session_call_activate() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
logind_session_call_activate_sync (
    LogindSession *proxy,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "Activate",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * logind_session_call_lock:
 * @proxy: A #LogindSessionProxy.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-freedesktop-login1-Session.Lock">Lock()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call logind_session_call_lock_finish() to get the result of the operation.
 *
 * See logind_session_call_lock_sync() for the synchronous, blocking version of this method.
 */
void
logind_session_call_lock (
    LogindSession *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "Lock",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * logind_session_call_lock_finish:
 * @proxy: A #LogindSessionProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to logind_session_call_lock().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with logind_session_call_lock().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
logind_session_call_lock_finish (
    LogindSession *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * logind_session_call_lock_sync:
 * @proxy: A #LogindSessionProxy.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-freedesktop-login1-Session.Lock">Lock()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See logind_session_call_lock() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
logind_session_call_lock_sync (
    LogindSession *proxy,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "Lock",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * logind_session_call_unlock:
 * @proxy: A #LogindSessionProxy.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-freedesktop-login1-Session.Unlock">Unlock()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call logind_session_call_unlock_finish() to get the result of the operation.
 *
 * See logind_session_call_unlock_sync() for the synchronous, blocking version of this method.
 */
void
logind_session_call_unlock (
    LogindSession *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "Unlock",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * logind_session_call_unlock_finish:
 * @proxy: A #LogindSessionProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to logind_session_call_unlock().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with logind_session_call_unlock().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
logind_session_call_unlock_finish (
    LogindSession *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * logind_session_call_unlock_sync:
 * @proxy: A #LogindSessionProxy.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-freedesktop-login1-Session.Unlock">Unlock()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See logind_session_call_unlock() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
logind_session_call_unlock_sync (
    LogindSession *proxy,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "Unlock",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * logind_session_call_set_idle_hint:
 * @proxy: A #LogindSessionProxy.
 * @arg_unnamed_arg0: Argument to pass with the method invocation.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-freedesktop-login1-Session.SetIdleHint">SetIdleHint()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call logind_session_call_set_idle_hint_finish() to get the result of the operation.
 *
 * See logind_session_call_set_idle_hint_sync() for the synchronous, blocking version of this method.
 */
void
logind_session_call_set_idle_hint (
    LogindSession *proxy,
    gboolean arg_unnamed_arg0,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "SetIdleHint",
    g_variant_new ("(b)",
                   arg_unnamed_arg0),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * logind_session_call_set_idle_hint_finish:
 * @proxy: A #LogindSessionProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to logind_session_call_set_idle_hint().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with logind_session_call_set_idle_hint().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
logind_session_call_set_idle_hint_finish (
    LogindSession *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * logind_session_call_set_idle_hint_sync:
 * @proxy: A #LogindSessionProxy.
 * @arg_unnamed_arg0: Argument to pass with the method invocation.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-freedesktop-login1-Session.SetIdleHint">SetIdleHint()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See logind_session_call_set_idle_hint() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
logind_session_call_set_idle_hint_sync (
    LogindSession *proxy,
    gboolean arg_unnamed_arg0,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "SetIdleHint",
    g_variant_new ("(b)",
                   arg_unnamed_arg0),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * logind_session_call_set_locked_hint:
 * @proxy: A #LogindSessionProxy.
 * @arg_unnamed_arg0: Argument to pass with the method invocation.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-freedesktop-login1-Session.SetLockedHint">SetLockedHint()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call logind_session_call_set_locked_hint_finish() to get the result of the operation.
 *
 * See logind_session_call_set_locked_hint_sync() for the synchronous, blocking version of this method.
 */
void
logind_session_call_set_locked_hint (
    LogindSession *proxy,
    gboolean arg_unnamed_arg0,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "SetLockedHint",
    g_variant_new ("(b)",
                   arg_unnamed_arg0),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * logind_session_call_set_locked_hint_finish:
 * @proxy: A #LogindSessionProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to logind_session_call_set_locked_hint().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with logind_session_call_set_locked_hint().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
logind_session_call_set_locked_hint_finish (
    LogindSession *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * logind_session_call_set_locked_hint_sync:
 * @proxy: A #LogindSessionProxy.
 * @arg_unnamed_arg0: Argument to pass with the method invocation.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-freedesktop-login1-Session.SetLockedHint">SetLockedHint()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See logind_session_call_set_locked_hint() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
logind_session_call_set_locked_hint_sync (
    LogindSession *proxy,
    gboolean arg_unnamed_arg0,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "SetLockedHint",
    g_variant_new ("(b)",
                   arg_unnamed_arg0),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * logind_session_call_kill:
 * @proxy: A #LogindSessionProxy.
 * @arg_unnamed_arg0: Argument to pass with the method invocation.
 * @arg_unnamed_arg1: Argument to pass with the method invocation.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-freedesktop-login1-Session.Kill">Kill()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call logind_session_call_kill_finish() to get the result of the operation.
 *
 * See logind_session_call_kill_sync() for the synchronous, blocking version of this method.
 */
void
logind_session_call_kill (
    LogindSession *proxy,
    const gchar *arg_unnamed_arg0,
    gint arg_unnamed_arg1,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "Kill",
    g_variant_new ("(si)",
                   arg_unnamed_arg0,
                   arg_unnamed_arg1),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * logind_session_call_kill_finish:
 * @proxy: A #LogindSessionProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to logind_session_call_kill().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with logind_session_call_kill().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
logind_session_call_kill_finish (
    LogindSession *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * logind_session_call_kill_sync:
 * @proxy: A #LogindSessionProxy.
 * @arg_unnamed_arg0: Argument to pass with the method invocation.
 * @arg_unnamed_arg1: Argument to pass with the method invocation.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-freedesktop-login1-Session.Kill">Kill()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See logind_session_call_kill() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
logind_session_call_kill_sync (
    LogindSession *proxy,
    const gchar *arg_unnamed_arg0,
    gint arg_unnamed_arg1,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "Kill",
    g_variant_new ("(si)",
                   arg_unnamed_arg0,
                   arg_unnamed_arg1),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * logind_session_call_take_control:
 * @proxy: A #LogindSessionProxy.
 * @arg_unnamed_arg0: Argument to pass with the method invocation.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-freedesktop-login1-Session.TakeControl">TakeControl()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call logind_session_call_take_control_finish() to get the result of the operation.
 *
 * See logind_session_call_take_control_sync() for the synchronous, blocking version of this method.
 */
void
logind_session_call_take_control (
    LogindSession *proxy,
    gboolean arg_unnamed_arg0,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "TakeControl",
    g_variant_new ("(b)",
                   arg_unnamed_arg0),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * logind_session_call_take_control_finish:
 * @proxy: A #LogindSessionProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to logind_session_call_take_control().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with logind_session_call_take_control().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
logind_session_call_take_control_finish (
    LogindSession *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * logind_session_call_take_control_sync:
 * @proxy: A #LogindSessionProxy.
 * @arg_unnamed_arg0: Argument to pass with the method invocation.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-freedesktop-login1-Session.TakeControl">TakeControl()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See logind_session_call_take_control() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
logind_session_call_take_control_sync (
    LogindSession *proxy,
    gboolean arg_unnamed_arg0,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "TakeControl",
    g_variant_new ("(b)",
                   arg_unnamed_arg0),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * logind_session_call_release_control:
 * @proxy: A #LogindSessionProxy.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-freedesktop-login1-Session.ReleaseControl">ReleaseControl()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call logind_session_call_release_control_finish() to get the result of the operation.
 *
 * See logind_session_call_release_control_sync() for the synchronous, blocking version of this method.
 */
void
logind_session_call_release_control (
    LogindSession *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "ReleaseControl",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * logind_session_call_release_control_finish:
 * @proxy: A #LogindSessionProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to logind_session_call_release_control().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with logind_session_call_release_control().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
logind_session_call_release_control_finish (
    LogindSession *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * logind_session_call_release_control_sync:
 * @proxy: A #LogindSessionProxy.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-freedesktop-login1-Session.ReleaseControl">ReleaseControl()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See logind_session_call_release_control() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
logind_session_call_release_control_sync (
    LogindSession *proxy,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "ReleaseControl",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * logind_session_call_take_device:
 * @proxy: A #LogindSessionProxy.
 * @arg_unnamed_arg0: Argument to pass with the method invocation.
 * @arg_unnamed_arg1: Argument to pass with the method invocation.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-freedesktop-login1-Session.TakeDevice">TakeDevice()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call logind_session_call_take_device_finish() to get the result of the operation.
 *
 * See logind_session_call_take_device_sync() for the synchronous, blocking version of this method.
 */
void
logind_session_call_take_device (
    LogindSession *proxy,
    guint arg_unnamed_arg0,
    guint arg_unnamed_arg1,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "TakeDevice",
    g_variant_new ("(uu)",
                   arg_unnamed_arg0,
                   arg_unnamed_arg1),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * logind_session_call_take_device_finish:
 * @proxy: A #LogindSessionProxy.
 * @out_unnamed_arg2: (out): Return location for return parameter or %NULL to ignore.
 * @out_unnamed_arg3: (out): Return location for return parameter or %NULL to ignore.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to logind_session_call_take_device().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with logind_session_call_take_device().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
logind_session_call_take_device_finish (
    LogindSession *proxy,
    GVariant **out_unnamed_arg2,
    gboolean *out_unnamed_arg3,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(@hb)",
                 out_unnamed_arg2,
                 out_unnamed_arg3);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * logind_session_call_take_device_sync:
 * @proxy: A #LogindSessionProxy.
 * @arg_unnamed_arg0: Argument to pass with the method invocation.
 * @arg_unnamed_arg1: Argument to pass with the method invocation.
 * @out_unnamed_arg2: (out): Return location for return parameter or %NULL to ignore.
 * @out_unnamed_arg3: (out): Return location for return parameter or %NULL to ignore.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-freedesktop-login1-Session.TakeDevice">TakeDevice()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See logind_session_call_take_device() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
logind_session_call_take_device_sync (
    LogindSession *proxy,
    guint arg_unnamed_arg0,
    guint arg_unnamed_arg1,
    GVariant **out_unnamed_arg2,
    gboolean *out_unnamed_arg3,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "TakeDevice",
    g_variant_new ("(uu)",
                   arg_unnamed_arg0,
                   arg_unnamed_arg1),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(@hb)",
                 out_unnamed_arg2,
                 out_unnamed_arg3);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * logind_session_call_release_device:
 * @proxy: A #LogindSessionProxy.
 * @arg_unnamed_arg0: Argument to pass with the method invocation.
 * @arg_unnamed_arg1: Argument to pass with the method invocation.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-freedesktop-login1-Session.ReleaseDevice">ReleaseDevice()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call logind_session_call_release_device_finish() to get the result of the operation.
 *
 * See logind_session_call_release_device_sync() for the synchronous, blocking version of this method.
 */
void
logind_session_call_release_device (
    LogindSession *proxy,
    guint arg_unnamed_arg0,
    guint arg_unnamed_arg1,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "ReleaseDevice",
    g_variant_new ("(uu)",
                   arg_unnamed_arg0,
                   arg_unnamed_arg1),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * logind_session_call_release_device_finish:
 * @proxy: A #LogindSessionProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to logind_session_call_release_device().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with logind_session_call_release_device().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
logind_session_call_release_device_finish (
    LogindSession *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * logind_session_call_release_device_sync:
 * @proxy: A #LogindSessionProxy.
 * @arg_unnamed_arg0: Argument to pass with the method invocation.
 * @arg_unnamed_arg1: Argument to pass with the method invocation.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-freedesktop-login1-Session.ReleaseDevice">ReleaseDevice()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See logind_session_call_release_device() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
logind_session_call_release_device_sync (
    LogindSession *proxy,
    guint arg_unnamed_arg0,
    guint arg_unnamed_arg1,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "ReleaseDevice",
    g_variant_new ("(uu)",
                   arg_unnamed_arg0,
                   arg_unnamed_arg1),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * logind_session_call_pause_device_complete:
 * @proxy: A #LogindSessionProxy.
 * @arg_unnamed_arg0: Argument to pass with the method invocation.
 * @arg_unnamed_arg1: Argument to pass with the method invocation.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-freedesktop-login1-Session.PauseDeviceComplete">PauseDeviceComplete()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call logind_session_call_pause_device_complete_finish() to get the result of the operation.
 *
 * See logind_session_call_pause_device_complete_sync() for the synchronous, blocking version of this method.
 */
void
logind_session_call_pause_device_complete (
    LogindSession *proxy,
    guint arg_unnamed_arg0,
    guint arg_unnamed_arg1,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "PauseDeviceComplete",
    g_variant_new ("(uu)",
                   arg_unnamed_arg0,
                   arg_unnamed_arg1),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * logind_session_call_pause_device_complete_finish:
 * @proxy: A #LogindSessionProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to logind_session_call_pause_device_complete().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with logind_session_call_pause_device_complete().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
logind_session_call_pause_device_complete_finish (
    LogindSession *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * logind_session_call_pause_device_complete_sync:
 * @proxy: A #LogindSessionProxy.
 * @arg_unnamed_arg0: Argument to pass with the method invocation.
 * @arg_unnamed_arg1: Argument to pass with the method invocation.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-freedesktop-login1-Session.PauseDeviceComplete">PauseDeviceComplete()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See logind_session_call_pause_device_complete() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
logind_session_call_pause_device_complete_sync (
    LogindSession *proxy,
    guint arg_unnamed_arg0,
    guint arg_unnamed_arg1,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "PauseDeviceComplete",
    g_variant_new ("(uu)",
                   arg_unnamed_arg0,
                   arg_unnamed_arg1),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * logind_session_complete_terminate:
 * @object: A #LogindSession.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-freedesktop-login1-Session.Terminate">Terminate()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
logind_session_complete_terminate (
    LogindSession *object,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/**
 * logind_session_complete_activate:
 * @object: A #LogindSession.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-freedesktop-login1-Session.Activate">Activate()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
logind_session_complete_activate (
    LogindSession *object,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/**
 * logind_session_complete_lock:
 * @object: A #LogindSession.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-freedesktop-login1-Session.Lock">Lock()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
logind_session_complete_lock (
    LogindSession *object,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/**
 * logind_session_complete_unlock:
 * @object: A #LogindSession.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-freedesktop-login1-Session.Unlock">Unlock()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
logind_session_complete_unlock (
    LogindSession *object,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/**
 * logind_session_complete_set_idle_hint:
 * @object: A #LogindSession.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-freedesktop-login1-Session.SetIdleHint">SetIdleHint()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
logind_session_complete_set_idle_hint (
    LogindSession *object,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/**
 * logind_session_complete_set_locked_hint:
 * @object: A #LogindSession.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-freedesktop-login1-Session.SetLockedHint">SetLockedHint()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
logind_session_complete_set_locked_hint (
    LogindSession *object,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/**
 * logind_session_complete_kill:
 * @object: A #LogindSession.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-freedesktop-login1-Session.Kill">Kill()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
logind_session_complete_kill (
    LogindSession *object,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/**
 * logind_session_complete_take_control:
 * @object: A #LogindSession.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-freedesktop-login1-Session.TakeControl">TakeControl()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
logind_session_complete_take_control (
    LogindSession *object,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/**
 * logind_session_complete_release_control:
 * @object: A #LogindSession.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-freedesktop-login1-Session.ReleaseControl">ReleaseControl()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
logind_session_complete_release_control (
    LogindSession *object,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/**
 * logind_session_complete_take_device:
 * @object: A #LogindSession.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 * @unnamed_arg2: Parameter to return.
 * @unnamed_arg3: Parameter to return.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-freedesktop-login1-Session.TakeDevice">TakeDevice()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
logind_session_complete_take_device (
    LogindSession *object,
    GDBusMethodInvocation *invocation,
    GVariant *unnamed_arg2,
    gboolean unnamed_arg3)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("(@hb)",
                   unnamed_arg2,
                   unnamed_arg3));
}

/**
 * logind_session_complete_release_device:
 * @object: A #LogindSession.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-freedesktop-login1-Session.ReleaseDevice">ReleaseDevice()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
logind_session_complete_release_device (
    LogindSession *object,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/**
 * logind_session_complete_pause_device_complete:
 * @object: A #LogindSession.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-freedesktop-login1-Session.PauseDeviceComplete">PauseDeviceComplete()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
logind_session_complete_pause_device_complete (
    LogindSession *object,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/* ------------------------------------------------------------------------ */

/**
 * LogindSessionProxy:
 *
 * The #LogindSessionProxy structure contains only private data and should only be accessed using the provided API.
 */

/**
 * LogindSessionProxyClass:
 * @parent_class: The parent class.
 *
 * Class structure for #LogindSessionProxy.
 */

struct _LogindSessionProxyPrivate
{
  GData *qdata;
};

static void logind_session_proxy_iface_init (LogindSessionIface *iface);

#if GLIB_VERSION_MAX_ALLOWED >= GLIB_VERSION_2_38
G_DEFINE_TYPE_WITH_CODE (LogindSessionProxy, logind_session_proxy, G_TYPE_DBUS_PROXY,
                         G_ADD_PRIVATE (LogindSessionProxy)
                         G_IMPLEMENT_INTERFACE (LOGIND_TYPE_SESSION, logind_session_proxy_iface_init))

#else
G_DEFINE_TYPE_WITH_CODE (LogindSessionProxy, logind_session_proxy, G_TYPE_DBUS_PROXY,
                         G_IMPLEMENT_INTERFACE (LOGIND_TYPE_SESSION, logind_session_proxy_iface_init))

#endif
static void
logind_session_proxy_finalize (GObject *object)
{
  LogindSessionProxy *proxy = LOGIND_SESSION_PROXY (object);
  g_datalist_clear (&proxy->priv->qdata);
  G_OBJECT_CLASS (logind_session_proxy_parent_class)->finalize (object);
}

static void
logind_session_proxy_get_property (GObject      *object,
  guint         prop_id,
  GValue       *value,
  GParamSpec   *pspec G_GNUC_UNUSED)
{
  const _ExtendedGDBusPropertyInfo *info;
  GVariant *variant;
  g_assert (prop_id != 0 && prop_id - 1 < 25);
  info = _logind_session_property_info_pointers[prop_id - 1];
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (object), info->parent_struct.name);
  if (info->use_gvariant)
    {
      g_value_set_variant (value, variant);
    }
  else
    {
      if (variant != NULL)
        g_dbus_gvariant_to_gvalue (variant, value);
    }
  if (variant != NULL)
    g_variant_unref (variant);
}

static void
logind_session_proxy_set_property_cb (GDBusProxy *proxy,
  GAsyncResult *res,
  gpointer      user_data)
{
  const _ExtendedGDBusPropertyInfo *info = user_data;
  GError *error;
  GVariant *_ret;
  error = NULL;
  _ret = g_dbus_proxy_call_finish (proxy, res, &error);
  if (!_ret)
    {
      g_warning ("Error setting property '%s' on interface org.freedesktop.login1.Session: %s (%s, %d)",
                 info->parent_struct.name, 
                 error->message, g_quark_to_string (error->domain), error->code);
      g_error_free (error);
    }
  else
    {
      g_variant_unref (_ret);
    }
}

static void
logind_session_proxy_set_property (GObject      *object,
  guint         prop_id,
  const GValue *value,
  GParamSpec   *pspec G_GNUC_UNUSED)
{
  const _ExtendedGDBusPropertyInfo *info;
  GVariant *variant;
  g_assert (prop_id != 0 && prop_id - 1 < 25);
  info = _logind_session_property_info_pointers[prop_id - 1];
  variant = g_dbus_gvalue_to_gvariant (value, G_VARIANT_TYPE (info->parent_struct.signature));
  g_dbus_proxy_call (G_DBUS_PROXY (object),
    "org.freedesktop.DBus.Properties.Set",
    g_variant_new ("(ssv)", "org.freedesktop.login1.Session", info->parent_struct.name, variant),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    NULL, (GAsyncReadyCallback) logind_session_proxy_set_property_cb, (GDBusPropertyInfo *) &info->parent_struct);
  g_variant_unref (variant);
}

static void
logind_session_proxy_g_signal (GDBusProxy *proxy,
  const gchar *sender_name G_GNUC_UNUSED,
  const gchar *signal_name,
  GVariant *parameters)
{
  _ExtendedGDBusSignalInfo *info;
  GVariantIter iter;
  GVariant *child;
  GValue *paramv;
  gsize num_params;
  gsize n;
  guint signal_id;
  info = (_ExtendedGDBusSignalInfo *) g_dbus_interface_info_lookup_signal ((GDBusInterfaceInfo *) &_logind_session_interface_info.parent_struct, signal_name);
  if (info == NULL)
    return;
  num_params = g_variant_n_children (parameters);
  paramv = g_new0 (GValue, num_params + 1);
  g_value_init (&paramv[0], LOGIND_TYPE_SESSION);
  g_value_set_object (&paramv[0], proxy);
  g_variant_iter_init (&iter, parameters);
  n = 1;
  while ((child = g_variant_iter_next_value (&iter)) != NULL)
    {
      _ExtendedGDBusArgInfo *arg_info = (_ExtendedGDBusArgInfo *) info->parent_struct.args[n - 1];
      if (arg_info->use_gvariant)
        {
          g_value_init (&paramv[n], G_TYPE_VARIANT);
          g_value_set_variant (&paramv[n], child);
          n++;
        }
      else
        g_dbus_gvariant_to_gvalue (child, &paramv[n++]);
      g_variant_unref (child);
    }
  signal_id = g_signal_lookup (info->signal_name, LOGIND_TYPE_SESSION);
  g_signal_emitv (paramv, signal_id, 0, NULL);
  for (n = 0; n < num_params + 1; n++)
    g_value_unset (&paramv[n]);
  g_free (paramv);
}

static void
logind_session_proxy_g_properties_changed (GDBusProxy *_proxy,
  GVariant *changed_properties,
  const gchar *const *invalidated_properties)
{
  LogindSessionProxy *proxy = LOGIND_SESSION_PROXY (_proxy);
  guint n;
  const gchar *key;
  GVariantIter *iter;
  _ExtendedGDBusPropertyInfo *info;
  g_variant_get (changed_properties, "a{sv}", &iter);
  while (g_variant_iter_next (iter, "{&sv}", &key, NULL))
    {
      info = (_ExtendedGDBusPropertyInfo *) g_dbus_interface_info_lookup_property ((GDBusInterfaceInfo *) &_logind_session_interface_info.parent_struct, key);
      g_datalist_remove_data (&proxy->priv->qdata, key);
      if (info != NULL)
        g_object_notify (G_OBJECT (proxy), info->hyphen_name);
    }
  g_variant_iter_free (iter);
  for (n = 0; invalidated_properties[n] != NULL; n++)
    {
      info = (_ExtendedGDBusPropertyInfo *) g_dbus_interface_info_lookup_property ((GDBusInterfaceInfo *) &_logind_session_interface_info.parent_struct, invalidated_properties[n]);
      g_datalist_remove_data (&proxy->priv->qdata, invalidated_properties[n]);
      if (info != NULL)
        g_object_notify (G_OBJECT (proxy), info->hyphen_name);
    }
}

static const gchar *
logind_session_proxy_get_id (LogindSession *object)
{
  LogindSessionProxy *proxy = LOGIND_SESSION_PROXY (object);
  GVariant *variant;
  const gchar *value = NULL;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "Id");
  if (variant != NULL)
    {
      value = g_variant_get_string (variant, NULL);
      g_variant_unref (variant);
    }
  return value;
}

static GVariant *
logind_session_proxy_get_user (LogindSession *object)
{
  LogindSessionProxy *proxy = LOGIND_SESSION_PROXY (object);
  GVariant *variant;
  GVariant *value = NULL;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "User");
  value = variant;
  if (variant != NULL)
    g_variant_unref (variant);
  return value;
}

static const gchar *
logind_session_proxy_get_name (LogindSession *object)
{
  LogindSessionProxy *proxy = LOGIND_SESSION_PROXY (object);
  GVariant *variant;
  const gchar *value = NULL;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "Name");
  if (variant != NULL)
    {
      value = g_variant_get_string (variant, NULL);
      g_variant_unref (variant);
    }
  return value;
}

static guint64 
logind_session_proxy_get_timestamp (LogindSession *object)
{
  LogindSessionProxy *proxy = LOGIND_SESSION_PROXY (object);
  GVariant *variant;
  guint64 value = 0;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "Timestamp");
  if (variant != NULL)
    {
      value = g_variant_get_uint64 (variant);
      g_variant_unref (variant);
    }
  return value;
}

static guint64 
logind_session_proxy_get_timestamp_monotonic (LogindSession *object)
{
  LogindSessionProxy *proxy = LOGIND_SESSION_PROXY (object);
  GVariant *variant;
  guint64 value = 0;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "TimestampMonotonic");
  if (variant != NULL)
    {
      value = g_variant_get_uint64 (variant);
      g_variant_unref (variant);
    }
  return value;
}

static guint 
logind_session_proxy_get_vtnr (LogindSession *object)
{
  LogindSessionProxy *proxy = LOGIND_SESSION_PROXY (object);
  GVariant *variant;
  guint value = 0;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "VTNr");
  if (variant != NULL)
    {
      value = g_variant_get_uint32 (variant);
      g_variant_unref (variant);
    }
  return value;
}

static GVariant *
logind_session_proxy_get_seat (LogindSession *object)
{
  LogindSessionProxy *proxy = LOGIND_SESSION_PROXY (object);
  GVariant *variant;
  GVariant *value = NULL;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "Seat");
  value = variant;
  if (variant != NULL)
    g_variant_unref (variant);
  return value;
}

static const gchar *
logind_session_proxy_get_tty (LogindSession *object)
{
  LogindSessionProxy *proxy = LOGIND_SESSION_PROXY (object);
  GVariant *variant;
  const gchar *value = NULL;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "TTY");
  if (variant != NULL)
    {
      value = g_variant_get_string (variant, NULL);
      g_variant_unref (variant);
    }
  return value;
}

static const gchar *
logind_session_proxy_get_display (LogindSession *object)
{
  LogindSessionProxy *proxy = LOGIND_SESSION_PROXY (object);
  GVariant *variant;
  const gchar *value = NULL;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "Display");
  if (variant != NULL)
    {
      value = g_variant_get_string (variant, NULL);
      g_variant_unref (variant);
    }
  return value;
}

static gboolean 
logind_session_proxy_get_remote (LogindSession *object)
{
  LogindSessionProxy *proxy = LOGIND_SESSION_PROXY (object);
  GVariant *variant;
  gboolean value = 0;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "Remote");
  if (variant != NULL)
    {
      value = g_variant_get_boolean (variant);
      g_variant_unref (variant);
    }
  return value;
}

static const gchar *
logind_session_proxy_get_remote_host (LogindSession *object)
{
  LogindSessionProxy *proxy = LOGIND_SESSION_PROXY (object);
  GVariant *variant;
  const gchar *value = NULL;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "RemoteHost");
  if (variant != NULL)
    {
      value = g_variant_get_string (variant, NULL);
      g_variant_unref (variant);
    }
  return value;
}

static const gchar *
logind_session_proxy_get_remote_user (LogindSession *object)
{
  LogindSessionProxy *proxy = LOGIND_SESSION_PROXY (object);
  GVariant *variant;
  const gchar *value = NULL;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "RemoteUser");
  if (variant != NULL)
    {
      value = g_variant_get_string (variant, NULL);
      g_variant_unref (variant);
    }
  return value;
}

static const gchar *
logind_session_proxy_get_service (LogindSession *object)
{
  LogindSessionProxy *proxy = LOGIND_SESSION_PROXY (object);
  GVariant *variant;
  const gchar *value = NULL;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "Service");
  if (variant != NULL)
    {
      value = g_variant_get_string (variant, NULL);
      g_variant_unref (variant);
    }
  return value;
}

static const gchar *
logind_session_proxy_get_desktop (LogindSession *object)
{
  LogindSessionProxy *proxy = LOGIND_SESSION_PROXY (object);
  GVariant *variant;
  const gchar *value = NULL;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "Desktop");
  if (variant != NULL)
    {
      value = g_variant_get_string (variant, NULL);
      g_variant_unref (variant);
    }
  return value;
}

static const gchar *
logind_session_proxy_get_scope (LogindSession *object)
{
  LogindSessionProxy *proxy = LOGIND_SESSION_PROXY (object);
  GVariant *variant;
  const gchar *value = NULL;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "Scope");
  if (variant != NULL)
    {
      value = g_variant_get_string (variant, NULL);
      g_variant_unref (variant);
    }
  return value;
}

static guint 
logind_session_proxy_get_leader (LogindSession *object)
{
  LogindSessionProxy *proxy = LOGIND_SESSION_PROXY (object);
  GVariant *variant;
  guint value = 0;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "Leader");
  if (variant != NULL)
    {
      value = g_variant_get_uint32 (variant);
      g_variant_unref (variant);
    }
  return value;
}

static guint 
logind_session_proxy_get_audit (LogindSession *object)
{
  LogindSessionProxy *proxy = LOGIND_SESSION_PROXY (object);
  GVariant *variant;
  guint value = 0;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "Audit");
  if (variant != NULL)
    {
      value = g_variant_get_uint32 (variant);
      g_variant_unref (variant);
    }
  return value;
}

static const gchar *
logind_session_proxy_get_type_ (LogindSession *object)
{
  LogindSessionProxy *proxy = LOGIND_SESSION_PROXY (object);
  GVariant *variant;
  const gchar *value = NULL;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "Type");
  if (variant != NULL)
    {
      value = g_variant_get_string (variant, NULL);
      g_variant_unref (variant);
    }
  return value;
}

static const gchar *
logind_session_proxy_get_class (LogindSession *object)
{
  LogindSessionProxy *proxy = LOGIND_SESSION_PROXY (object);
  GVariant *variant;
  const gchar *value = NULL;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "Class");
  if (variant != NULL)
    {
      value = g_variant_get_string (variant, NULL);
      g_variant_unref (variant);
    }
  return value;
}

static gboolean 
logind_session_proxy_get_active (LogindSession *object)
{
  LogindSessionProxy *proxy = LOGIND_SESSION_PROXY (object);
  GVariant *variant;
  gboolean value = 0;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "Active");
  if (variant != NULL)
    {
      value = g_variant_get_boolean (variant);
      g_variant_unref (variant);
    }
  return value;
}

static const gchar *
logind_session_proxy_get_state (LogindSession *object)
{
  LogindSessionProxy *proxy = LOGIND_SESSION_PROXY (object);
  GVariant *variant;
  const gchar *value = NULL;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "State");
  if (variant != NULL)
    {
      value = g_variant_get_string (variant, NULL);
      g_variant_unref (variant);
    }
  return value;
}

static gboolean 
logind_session_proxy_get_idle_hint (LogindSession *object)
{
  LogindSessionProxy *proxy = LOGIND_SESSION_PROXY (object);
  GVariant *variant;
  gboolean value = 0;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "IdleHint");
  if (variant != NULL)
    {
      value = g_variant_get_boolean (variant);
      g_variant_unref (variant);
    }
  return value;
}

static guint64 
logind_session_proxy_get_idle_since_hint (LogindSession *object)
{
  LogindSessionProxy *proxy = LOGIND_SESSION_PROXY (object);
  GVariant *variant;
  guint64 value = 0;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "IdleSinceHint");
  if (variant != NULL)
    {
      value = g_variant_get_uint64 (variant);
      g_variant_unref (variant);
    }
  return value;
}

static guint64 
logind_session_proxy_get_idle_since_hint_monotonic (LogindSession *object)
{
  LogindSessionProxy *proxy = LOGIND_SESSION_PROXY (object);
  GVariant *variant;
  guint64 value = 0;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "IdleSinceHintMonotonic");
  if (variant != NULL)
    {
      value = g_variant_get_uint64 (variant);
      g_variant_unref (variant);
    }
  return value;
}

static gboolean 
logind_session_proxy_get_locked_hint (LogindSession *object)
{
  LogindSessionProxy *proxy = LOGIND_SESSION_PROXY (object);
  GVariant *variant;
  gboolean value = 0;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "LockedHint");
  if (variant != NULL)
    {
      value = g_variant_get_boolean (variant);
      g_variant_unref (variant);
    }
  return value;
}

static void
logind_session_proxy_init (LogindSessionProxy *proxy)
{
#if GLIB_VERSION_MAX_ALLOWED >= GLIB_VERSION_2_38
  proxy->priv = logind_session_proxy_get_instance_private (proxy);
#else
  proxy->priv = G_TYPE_INSTANCE_GET_PRIVATE (proxy, LOGIND_TYPE_SESSION_PROXY, LogindSessionProxyPrivate);
#endif

  g_dbus_proxy_set_interface_info (G_DBUS_PROXY (proxy), logind_session_interface_info ());
}

static void
logind_session_proxy_class_init (LogindSessionProxyClass *klass)
{
  GObjectClass *gobject_class;
  GDBusProxyClass *proxy_class;

  gobject_class = G_OBJECT_CLASS (klass);
  gobject_class->finalize     = logind_session_proxy_finalize;
  gobject_class->get_property = logind_session_proxy_get_property;
  gobject_class->set_property = logind_session_proxy_set_property;

  proxy_class = G_DBUS_PROXY_CLASS (klass);
  proxy_class->g_signal = logind_session_proxy_g_signal;
  proxy_class->g_properties_changed = logind_session_proxy_g_properties_changed;

  logind_session_override_properties (gobject_class, 1);

#if GLIB_VERSION_MAX_ALLOWED < GLIB_VERSION_2_38
  g_type_class_add_private (klass, sizeof (LogindSessionProxyPrivate));
#endif
}

static void
logind_session_proxy_iface_init (LogindSessionIface *iface)
{
  iface->get_id = logind_session_proxy_get_id;
  iface->get_user = logind_session_proxy_get_user;
  iface->get_name = logind_session_proxy_get_name;
  iface->get_timestamp = logind_session_proxy_get_timestamp;
  iface->get_timestamp_monotonic = logind_session_proxy_get_timestamp_monotonic;
  iface->get_vtnr = logind_session_proxy_get_vtnr;
  iface->get_seat = logind_session_proxy_get_seat;
  iface->get_tty = logind_session_proxy_get_tty;
  iface->get_display = logind_session_proxy_get_display;
  iface->get_remote = logind_session_proxy_get_remote;
  iface->get_remote_host = logind_session_proxy_get_remote_host;
  iface->get_remote_user = logind_session_proxy_get_remote_user;
  iface->get_service = logind_session_proxy_get_service;
  iface->get_desktop = logind_session_proxy_get_desktop;
  iface->get_scope = logind_session_proxy_get_scope;
  iface->get_leader = logind_session_proxy_get_leader;
  iface->get_audit = logind_session_proxy_get_audit;
  iface->get_type_ = logind_session_proxy_get_type_;
  iface->get_class = logind_session_proxy_get_class;
  iface->get_active = logind_session_proxy_get_active;
  iface->get_state = logind_session_proxy_get_state;
  iface->get_idle_hint = logind_session_proxy_get_idle_hint;
  iface->get_idle_since_hint = logind_session_proxy_get_idle_since_hint;
  iface->get_idle_since_hint_monotonic = logind_session_proxy_get_idle_since_hint_monotonic;
  iface->get_locked_hint = logind_session_proxy_get_locked_hint;
}

/**
 * logind_session_proxy_new:
 * @connection: A #GDBusConnection.
 * @flags: Flags from the #GDBusProxyFlags enumeration.
 * @name: (nullable): A bus name (well-known or unique) or %NULL if @connection is not a message bus connection.
 * @object_path: An object path.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously creates a proxy for the D-Bus interface <link linkend="gdbus-interface-org-freedesktop-login1-Session.top_of_page">org.freedesktop.login1.Session</link>. See g_dbus_proxy_new() for more details.
 *
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call logind_session_proxy_new_finish() to get the result of the operation.
 *
 * See logind_session_proxy_new_sync() for the synchronous, blocking version of this constructor.
 */
void
logind_session_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data)
{
  g_async_initable_new_async (LOGIND_TYPE_SESSION_PROXY, G_PRIORITY_DEFAULT, cancellable, callback, user_data, "g-flags", flags, "g-name", name, "g-connection", connection, "g-object-path", object_path, "g-interface-name", "org.freedesktop.login1.Session", NULL);
}

/**
 * logind_session_proxy_new_finish:
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to logind_session_proxy_new().
 * @error: Return location for error or %NULL
 *
 * Finishes an operation started with logind_session_proxy_new().
 *
 * Returns: (transfer full) (type LogindSessionProxy): The constructed proxy object or %NULL if @error is set.
 */
LogindSession *
logind_session_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error)
{
  GObject *ret;
  GObject *source_object;
  source_object = g_async_result_get_source_object (res);
  ret = g_async_initable_new_finish (G_ASYNC_INITABLE (source_object), res, error);
  g_object_unref (source_object);
  if (ret != NULL)
    return LOGIND_SESSION (ret);
  else
    return NULL;
}

/**
 * logind_session_proxy_new_sync:
 * @connection: A #GDBusConnection.
 * @flags: Flags from the #GDBusProxyFlags enumeration.
 * @name: (nullable): A bus name (well-known or unique) or %NULL if @connection is not a message bus connection.
 * @object_path: An object path.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL
 *
 * Synchronously creates a proxy for the D-Bus interface <link linkend="gdbus-interface-org-freedesktop-login1-Session.top_of_page">org.freedesktop.login1.Session</link>. See g_dbus_proxy_new_sync() for more details.
 *
 * The calling thread is blocked until a reply is received.
 *
 * See logind_session_proxy_new() for the asynchronous version of this constructor.
 *
 * Returns: (transfer full) (type LogindSessionProxy): The constructed proxy object or %NULL if @error is set.
 */
LogindSession *
logind_session_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error)
{
  GInitable *ret;
  ret = g_initable_new (LOGIND_TYPE_SESSION_PROXY, cancellable, error, "g-flags", flags, "g-name", name, "g-connection", connection, "g-object-path", object_path, "g-interface-name", "org.freedesktop.login1.Session", NULL);
  if (ret != NULL)
    return LOGIND_SESSION (ret);
  else
    return NULL;
}


/**
 * logind_session_proxy_new_for_bus:
 * @bus_type: A #GBusType.
 * @flags: Flags from the #GDBusProxyFlags enumeration.
 * @name: A bus name (well-known or unique).
 * @object_path: An object path.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied.
 * @user_data: User data to pass to @callback.
 *
 * Like logind_session_proxy_new() but takes a #GBusType instead of a #GDBusConnection.
 *
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call logind_session_proxy_new_for_bus_finish() to get the result of the operation.
 *
 * See logind_session_proxy_new_for_bus_sync() for the synchronous, blocking version of this constructor.
 */
void
logind_session_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data)
{
  g_async_initable_new_async (LOGIND_TYPE_SESSION_PROXY, G_PRIORITY_DEFAULT, cancellable, callback, user_data, "g-flags", flags, "g-name", name, "g-bus-type", bus_type, "g-object-path", object_path, "g-interface-name", "org.freedesktop.login1.Session", NULL);
}

/**
 * logind_session_proxy_new_for_bus_finish:
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to logind_session_proxy_new_for_bus().
 * @error: Return location for error or %NULL
 *
 * Finishes an operation started with logind_session_proxy_new_for_bus().
 *
 * Returns: (transfer full) (type LogindSessionProxy): The constructed proxy object or %NULL if @error is set.
 */
LogindSession *
logind_session_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error)
{
  GObject *ret;
  GObject *source_object;
  source_object = g_async_result_get_source_object (res);
  ret = g_async_initable_new_finish (G_ASYNC_INITABLE (source_object), res, error);
  g_object_unref (source_object);
  if (ret != NULL)
    return LOGIND_SESSION (ret);
  else
    return NULL;
}

/**
 * logind_session_proxy_new_for_bus_sync:
 * @bus_type: A #GBusType.
 * @flags: Flags from the #GDBusProxyFlags enumeration.
 * @name: A bus name (well-known or unique).
 * @object_path: An object path.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL
 *
 * Like logind_session_proxy_new_sync() but takes a #GBusType instead of a #GDBusConnection.
 *
 * The calling thread is blocked until a reply is received.
 *
 * See logind_session_proxy_new_for_bus() for the asynchronous version of this constructor.
 *
 * Returns: (transfer full) (type LogindSessionProxy): The constructed proxy object or %NULL if @error is set.
 */
LogindSession *
logind_session_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error)
{
  GInitable *ret;
  ret = g_initable_new (LOGIND_TYPE_SESSION_PROXY, cancellable, error, "g-flags", flags, "g-name", name, "g-bus-type", bus_type, "g-object-path", object_path, "g-interface-name", "org.freedesktop.login1.Session", NULL);
  if (ret != NULL)
    return LOGIND_SESSION (ret);
  else
    return NULL;
}


/* ------------------------------------------------------------------------ */

/**
 * LogindSessionSkeleton:
 *
 * The #LogindSessionSkeleton structure contains only private data and should only be accessed using the provided API.
 */

/**
 * LogindSessionSkeletonClass:
 * @parent_class: The parent class.
 *
 * Class structure for #LogindSessionSkeleton.
 */

struct _LogindSessionSkeletonPrivate
{
  GValue *properties;
  GList *changed_properties;
  GSource *changed_properties_idle_source;
  GMainContext *context;
  GMutex lock;
};

static void
_logind_session_skeleton_handle_method_call (
  GDBusConnection *connection G_GNUC_UNUSED,
  const gchar *sender G_GNUC_UNUSED,
  const gchar *object_path G_GNUC_UNUSED,
  const gchar *interface_name,
  const gchar *method_name,
  GVariant *parameters,
  GDBusMethodInvocation *invocation,
  gpointer user_data)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (user_data);
  _ExtendedGDBusMethodInfo *info;
  GVariantIter iter;
  GVariant *child;
  GValue *paramv;
  gsize num_params;
  guint num_extra;
  gsize n;
  guint signal_id;
  GValue return_value = G_VALUE_INIT;
  info = (_ExtendedGDBusMethodInfo *) g_dbus_method_invocation_get_method_info (invocation);
  g_assert (info != NULL);
  num_params = g_variant_n_children (parameters);
  num_extra = info->pass_fdlist ? 3 : 2;  paramv = g_new0 (GValue, num_params + num_extra);
  n = 0;
  g_value_init (&paramv[n], LOGIND_TYPE_SESSION);
  g_value_set_object (&paramv[n++], skeleton);
  g_value_init (&paramv[n], G_TYPE_DBUS_METHOD_INVOCATION);
  g_value_set_object (&paramv[n++], invocation);
  if (info->pass_fdlist)
    {
#ifdef G_OS_UNIX
      g_value_init (&paramv[n], G_TYPE_UNIX_FD_LIST);
      g_value_set_object (&paramv[n++], g_dbus_message_get_unix_fd_list (g_dbus_method_invocation_get_message (invocation)));
#else
      g_assert_not_reached ();
#endif
    }
  g_variant_iter_init (&iter, parameters);
  while ((child = g_variant_iter_next_value (&iter)) != NULL)
    {
      _ExtendedGDBusArgInfo *arg_info = (_ExtendedGDBusArgInfo *) info->parent_struct.in_args[n - num_extra];
      if (arg_info->use_gvariant)
        {
          g_value_init (&paramv[n], G_TYPE_VARIANT);
          g_value_set_variant (&paramv[n], child);
          n++;
        }
      else
        g_dbus_gvariant_to_gvalue (child, &paramv[n++]);
      g_variant_unref (child);
    }
  signal_id = g_signal_lookup (info->signal_name, LOGIND_TYPE_SESSION);
  g_value_init (&return_value, G_TYPE_BOOLEAN);
  g_signal_emitv (paramv, signal_id, 0, &return_value);
  if (!g_value_get_boolean (&return_value))
    g_dbus_method_invocation_return_error (invocation, G_DBUS_ERROR, G_DBUS_ERROR_UNKNOWN_METHOD, "Method %s is not implemented on interface %s", method_name, interface_name);
  g_value_unset (&return_value);
  for (n = 0; n < num_params + num_extra; n++)
    g_value_unset (&paramv[n]);
  g_free (paramv);
}

static GVariant *
_logind_session_skeleton_handle_get_property (
  GDBusConnection *connection G_GNUC_UNUSED,
  const gchar *sender G_GNUC_UNUSED,
  const gchar *object_path G_GNUC_UNUSED,
  const gchar *interface_name G_GNUC_UNUSED,
  const gchar *property_name,
  GError **error,
  gpointer user_data)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (user_data);
  GValue value = G_VALUE_INIT;
  GParamSpec *pspec;
  _ExtendedGDBusPropertyInfo *info;
  GVariant *ret;
  ret = NULL;
  info = (_ExtendedGDBusPropertyInfo *) g_dbus_interface_info_lookup_property ((GDBusInterfaceInfo *) &_logind_session_interface_info.parent_struct, property_name);
  g_assert (info != NULL);
  pspec = g_object_class_find_property (G_OBJECT_GET_CLASS (skeleton), info->hyphen_name);
  if (pspec == NULL)
    {
      g_set_error (error, G_DBUS_ERROR, G_DBUS_ERROR_INVALID_ARGS, "No property with name %s", property_name);
    }
  else
    {
      g_value_init (&value, pspec->value_type);
      g_object_get_property (G_OBJECT (skeleton), info->hyphen_name, &value);
      ret = g_dbus_gvalue_to_gvariant (&value, G_VARIANT_TYPE (info->parent_struct.signature));
      g_value_unset (&value);
    }
  return ret;
}

static gboolean
_logind_session_skeleton_handle_set_property (
  GDBusConnection *connection G_GNUC_UNUSED,
  const gchar *sender G_GNUC_UNUSED,
  const gchar *object_path G_GNUC_UNUSED,
  const gchar *interface_name G_GNUC_UNUSED,
  const gchar *property_name,
  GVariant *variant,
  GError **error,
  gpointer user_data)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (user_data);
  GValue value = G_VALUE_INIT;
  GParamSpec *pspec;
  _ExtendedGDBusPropertyInfo *info;
  gboolean ret;
  ret = FALSE;
  info = (_ExtendedGDBusPropertyInfo *) g_dbus_interface_info_lookup_property ((GDBusInterfaceInfo *) &_logind_session_interface_info.parent_struct, property_name);
  g_assert (info != NULL);
  pspec = g_object_class_find_property (G_OBJECT_GET_CLASS (skeleton), info->hyphen_name);
  if (pspec == NULL)
    {
      g_set_error (error, G_DBUS_ERROR, G_DBUS_ERROR_INVALID_ARGS, "No property with name %s", property_name);
    }
  else
    {
      if (info->use_gvariant)
        g_value_set_variant (&value, variant);
      else
        g_dbus_gvariant_to_gvalue (variant, &value);
      g_object_set_property (G_OBJECT (skeleton), info->hyphen_name, &value);
      g_value_unset (&value);
      ret = TRUE;
    }
  return ret;
}

static const GDBusInterfaceVTable _logind_session_skeleton_vtable =
{
  _logind_session_skeleton_handle_method_call,
  _logind_session_skeleton_handle_get_property,
  _logind_session_skeleton_handle_set_property,
  {NULL}
};

static GDBusInterfaceInfo *
logind_session_skeleton_dbus_interface_get_info (GDBusInterfaceSkeleton *skeleton G_GNUC_UNUSED)
{
  return logind_session_interface_info ();
}

static GDBusInterfaceVTable *
logind_session_skeleton_dbus_interface_get_vtable (GDBusInterfaceSkeleton *skeleton G_GNUC_UNUSED)
{
  return (GDBusInterfaceVTable *) &_logind_session_skeleton_vtable;
}

static GVariant *
logind_session_skeleton_dbus_interface_get_properties (GDBusInterfaceSkeleton *_skeleton)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (_skeleton);

  GVariantBuilder builder;
  guint n;
  g_variant_builder_init (&builder, G_VARIANT_TYPE ("a{sv}"));
  if (_logind_session_interface_info.parent_struct.properties == NULL)
    goto out;
  for (n = 0; _logind_session_interface_info.parent_struct.properties[n] != NULL; n++)
    {
      GDBusPropertyInfo *info = _logind_session_interface_info.parent_struct.properties[n];
      if (info->flags & G_DBUS_PROPERTY_INFO_FLAGS_READABLE)
        {
          GVariant *value;
          value = _logind_session_skeleton_handle_get_property (g_dbus_interface_skeleton_get_connection (G_DBUS_INTERFACE_SKELETON (skeleton)), NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.freedesktop.login1.Session", info->name, NULL, skeleton);
          if (value != NULL)
            {
              g_variant_take_ref (value);
              g_variant_builder_add (&builder, "{sv}", info->name, value);
              g_variant_unref (value);
            }
        }
    }
out:
  return g_variant_builder_end (&builder);
}

static gboolean _logind_session_emit_changed (gpointer user_data);

static void
logind_session_skeleton_dbus_interface_flush (GDBusInterfaceSkeleton *_skeleton)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (_skeleton);
  gboolean emit_changed = FALSE;

  g_mutex_lock (&skeleton->priv->lock);
  if (skeleton->priv->changed_properties_idle_source != NULL)
    {
      g_source_destroy (skeleton->priv->changed_properties_idle_source);
      skeleton->priv->changed_properties_idle_source = NULL;
      emit_changed = TRUE;
    }
  g_mutex_unlock (&skeleton->priv->lock);

  if (emit_changed)
    _logind_session_emit_changed (skeleton);
}

static void
_logind_session_on_signal_pause_device (
    LogindSession *object,
    guint arg_unnamed_arg0,
    guint arg_unnamed_arg1,
    const gchar *arg_unnamed_arg2)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("(uus)",
                   arg_unnamed_arg0,
                   arg_unnamed_arg1,
                   arg_unnamed_arg2));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.freedesktop.login1.Session", "PauseDevice",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void
_logind_session_on_signal_resume_device (
    LogindSession *object,
    guint arg_unnamed_arg0,
    guint arg_unnamed_arg1,
    GVariant *arg_unnamed_arg2)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("(uu@h)",
                   arg_unnamed_arg0,
                   arg_unnamed_arg1,
                   arg_unnamed_arg2));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.freedesktop.login1.Session", "ResumeDevice",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void
_logind_session_on_signal_lock (
    LogindSession *object)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("()"));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.freedesktop.login1.Session", "Lock",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void
_logind_session_on_signal_unlock (
    LogindSession *object)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("()"));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.freedesktop.login1.Session", "Unlock",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void logind_session_skeleton_iface_init (LogindSessionIface *iface);
#if GLIB_VERSION_MAX_ALLOWED >= GLIB_VERSION_2_38
G_DEFINE_TYPE_WITH_CODE (LogindSessionSkeleton, logind_session_skeleton, G_TYPE_DBUS_INTERFACE_SKELETON,
                         G_ADD_PRIVATE (LogindSessionSkeleton)
                         G_IMPLEMENT_INTERFACE (LOGIND_TYPE_SESSION, logind_session_skeleton_iface_init))

#else
G_DEFINE_TYPE_WITH_CODE (LogindSessionSkeleton, logind_session_skeleton, G_TYPE_DBUS_INTERFACE_SKELETON,
                         G_IMPLEMENT_INTERFACE (LOGIND_TYPE_SESSION, logind_session_skeleton_iface_init))

#endif
static void
logind_session_skeleton_finalize (GObject *object)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);
  guint n;
  for (n = 0; n < 25; n++)
    g_value_unset (&skeleton->priv->properties[n]);
  g_free (skeleton->priv->properties);
  g_list_free_full (skeleton->priv->changed_properties, (GDestroyNotify) _changed_property_free);
  if (skeleton->priv->changed_properties_idle_source != NULL)
    g_source_destroy (skeleton->priv->changed_properties_idle_source);
  g_main_context_unref (skeleton->priv->context);
  g_mutex_clear (&skeleton->priv->lock);
  G_OBJECT_CLASS (logind_session_skeleton_parent_class)->finalize (object);
}

static void
logind_session_skeleton_get_property (GObject      *object,
  guint         prop_id,
  GValue       *value,
  GParamSpec   *pspec G_GNUC_UNUSED)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);
  g_assert (prop_id != 0 && prop_id - 1 < 25);
  g_mutex_lock (&skeleton->priv->lock);
  g_value_copy (&skeleton->priv->properties[prop_id - 1], value);
  g_mutex_unlock (&skeleton->priv->lock);
}

static gboolean
_logind_session_emit_changed (gpointer user_data)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (user_data);
  GList *l;
  GVariantBuilder builder;
  GVariantBuilder invalidated_builder;
  guint num_changes;

  g_mutex_lock (&skeleton->priv->lock);
  g_variant_builder_init (&builder, G_VARIANT_TYPE ("a{sv}"));
  g_variant_builder_init (&invalidated_builder, G_VARIANT_TYPE ("as"));
  for (l = skeleton->priv->changed_properties, num_changes = 0; l != NULL; l = l->next)
    {
      ChangedProperty *cp = l->data;
      GVariant *variant;
      const GValue *cur_value;

      cur_value = &skeleton->priv->properties[cp->prop_id - 1];
      if (!_g_value_equal (cur_value, &cp->orig_value))
        {
          variant = g_dbus_gvalue_to_gvariant (cur_value, G_VARIANT_TYPE (cp->info->parent_struct.signature));
          g_variant_builder_add (&builder, "{sv}", cp->info->parent_struct.name, variant);
          g_variant_unref (variant);
          num_changes++;
        }
    }
  if (num_changes > 0)
    {
      GList *connections, *ll;
      GVariant *signal_variant;
      signal_variant = g_variant_ref_sink (g_variant_new ("(sa{sv}as)", "org.freedesktop.login1.Session",
                                           &builder, &invalidated_builder));
      connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));
      for (ll = connections; ll != NULL; ll = ll->next)
        {
          GDBusConnection *connection = ll->data;

          g_dbus_connection_emit_signal (connection,
                                         NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)),
                                         "org.freedesktop.DBus.Properties",
                                         "PropertiesChanged",
                                         signal_variant,
                                         NULL);
        }
      g_variant_unref (signal_variant);
      g_list_free_full (connections, g_object_unref);
    }
  else
    {
      g_variant_builder_clear (&builder);
      g_variant_builder_clear (&invalidated_builder);
    }
  g_list_free_full (skeleton->priv->changed_properties, (GDestroyNotify) _changed_property_free);
  skeleton->priv->changed_properties = NULL;
  skeleton->priv->changed_properties_idle_source = NULL;
  g_mutex_unlock (&skeleton->priv->lock);
  return FALSE;
}

static void
_logind_session_schedule_emit_changed (LogindSessionSkeleton *skeleton, const _ExtendedGDBusPropertyInfo *info, guint prop_id, const GValue *orig_value)
{
  ChangedProperty *cp;
  GList *l;
  cp = NULL;
  for (l = skeleton->priv->changed_properties; l != NULL; l = l->next)
    {
      ChangedProperty *i_cp = l->data;
      if (i_cp->info == info)
        {
          cp = i_cp;
          break;
        }
    }
  if (cp == NULL)
    {
      cp = g_new0 (ChangedProperty, 1);
      cp->prop_id = prop_id;
      cp->info = info;
      skeleton->priv->changed_properties = g_list_prepend (skeleton->priv->changed_properties, cp);
      g_value_init (&cp->orig_value, G_VALUE_TYPE (orig_value));
      g_value_copy (orig_value, &cp->orig_value);
    }
}

static void
logind_session_skeleton_notify (GObject      *object,
  GParamSpec *pspec G_GNUC_UNUSED)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);
  g_mutex_lock (&skeleton->priv->lock);
  if (skeleton->priv->changed_properties != NULL &&
      skeleton->priv->changed_properties_idle_source == NULL)
    {
      skeleton->priv->changed_properties_idle_source = g_idle_source_new ();
      g_source_set_priority (skeleton->priv->changed_properties_idle_source, G_PRIORITY_DEFAULT);
      g_source_set_callback (skeleton->priv->changed_properties_idle_source, _logind_session_emit_changed, g_object_ref (skeleton), (GDestroyNotify) g_object_unref);
      g_source_set_name (skeleton->priv->changed_properties_idle_source, "[generated] _logind_session_emit_changed");
      g_source_attach (skeleton->priv->changed_properties_idle_source, skeleton->priv->context);
      g_source_unref (skeleton->priv->changed_properties_idle_source);
    }
  g_mutex_unlock (&skeleton->priv->lock);
}

static void
logind_session_skeleton_set_property (GObject      *object,
  guint         prop_id,
  const GValue *value,
  GParamSpec   *pspec)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);
  g_assert (prop_id != 0 && prop_id - 1 < 25);
  g_mutex_lock (&skeleton->priv->lock);
  g_object_freeze_notify (object);
  if (!_g_value_equal (value, &skeleton->priv->properties[prop_id - 1]))
    {
      if (g_dbus_interface_skeleton_get_connection (G_DBUS_INTERFACE_SKELETON (skeleton)) != NULL)
        _logind_session_schedule_emit_changed (skeleton, _logind_session_property_info_pointers[prop_id - 1], prop_id, &skeleton->priv->properties[prop_id - 1]);
      g_value_copy (value, &skeleton->priv->properties[prop_id - 1]);
      g_object_notify_by_pspec (object, pspec);
    }
  g_mutex_unlock (&skeleton->priv->lock);
  g_object_thaw_notify (object);
}

static void
logind_session_skeleton_init (LogindSessionSkeleton *skeleton)
{
#if GLIB_VERSION_MAX_ALLOWED >= GLIB_VERSION_2_38
  skeleton->priv = logind_session_skeleton_get_instance_private (skeleton);
#else
  skeleton->priv = G_TYPE_INSTANCE_GET_PRIVATE (skeleton, LOGIND_TYPE_SESSION_SKELETON, LogindSessionSkeletonPrivate);
#endif

  g_mutex_init (&skeleton->priv->lock);
  skeleton->priv->context = g_main_context_ref_thread_default ();
  skeleton->priv->properties = g_new0 (GValue, 25);
  g_value_init (&skeleton->priv->properties[0], G_TYPE_STRING);
  g_value_init (&skeleton->priv->properties[1], G_TYPE_VARIANT);
  g_value_init (&skeleton->priv->properties[2], G_TYPE_STRING);
  g_value_init (&skeleton->priv->properties[3], G_TYPE_UINT64);
  g_value_init (&skeleton->priv->properties[4], G_TYPE_UINT64);
  g_value_init (&skeleton->priv->properties[5], G_TYPE_UINT);
  g_value_init (&skeleton->priv->properties[6], G_TYPE_VARIANT);
  g_value_init (&skeleton->priv->properties[7], G_TYPE_STRING);
  g_value_init (&skeleton->priv->properties[8], G_TYPE_STRING);
  g_value_init (&skeleton->priv->properties[9], G_TYPE_BOOLEAN);
  g_value_init (&skeleton->priv->properties[10], G_TYPE_STRING);
  g_value_init (&skeleton->priv->properties[11], G_TYPE_STRING);
  g_value_init (&skeleton->priv->properties[12], G_TYPE_STRING);
  g_value_init (&skeleton->priv->properties[13], G_TYPE_STRING);
  g_value_init (&skeleton->priv->properties[14], G_TYPE_STRING);
  g_value_init (&skeleton->priv->properties[15], G_TYPE_UINT);
  g_value_init (&skeleton->priv->properties[16], G_TYPE_UINT);
  g_value_init (&skeleton->priv->properties[17], G_TYPE_STRING);
  g_value_init (&skeleton->priv->properties[18], G_TYPE_STRING);
  g_value_init (&skeleton->priv->properties[19], G_TYPE_BOOLEAN);
  g_value_init (&skeleton->priv->properties[20], G_TYPE_STRING);
  g_value_init (&skeleton->priv->properties[21], G_TYPE_BOOLEAN);
  g_value_init (&skeleton->priv->properties[22], G_TYPE_UINT64);
  g_value_init (&skeleton->priv->properties[23], G_TYPE_UINT64);
  g_value_init (&skeleton->priv->properties[24], G_TYPE_BOOLEAN);
}

static const gchar *
logind_session_skeleton_get_id (LogindSession *object)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);
  const gchar *value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_value_get_string (&(skeleton->priv->properties[0]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static GVariant *
logind_session_skeleton_get_user (LogindSession *object)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);
  GVariant *value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_value_get_variant (&(skeleton->priv->properties[1]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static const gchar *
logind_session_skeleton_get_name (LogindSession *object)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);
  const gchar *value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_value_get_string (&(skeleton->priv->properties[2]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static guint64 
logind_session_skeleton_get_timestamp (LogindSession *object)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);
  guint64 value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_value_get_uint64 (&(skeleton->priv->properties[3]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static guint64 
logind_session_skeleton_get_timestamp_monotonic (LogindSession *object)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);
  guint64 value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_value_get_uint64 (&(skeleton->priv->properties[4]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static guint 
logind_session_skeleton_get_vtnr (LogindSession *object)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);
  guint value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_value_get_uint (&(skeleton->priv->properties[5]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static GVariant *
logind_session_skeleton_get_seat (LogindSession *object)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);
  GVariant *value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_value_get_variant (&(skeleton->priv->properties[6]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static const gchar *
logind_session_skeleton_get_tty (LogindSession *object)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);
  const gchar *value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_value_get_string (&(skeleton->priv->properties[7]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static const gchar *
logind_session_skeleton_get_display (LogindSession *object)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);
  const gchar *value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_value_get_string (&(skeleton->priv->properties[8]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static gboolean 
logind_session_skeleton_get_remote (LogindSession *object)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);
  gboolean value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_value_get_boolean (&(skeleton->priv->properties[9]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static const gchar *
logind_session_skeleton_get_remote_host (LogindSession *object)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);
  const gchar *value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_value_get_string (&(skeleton->priv->properties[10]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static const gchar *
logind_session_skeleton_get_remote_user (LogindSession *object)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);
  const gchar *value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_value_get_string (&(skeleton->priv->properties[11]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static const gchar *
logind_session_skeleton_get_service (LogindSession *object)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);
  const gchar *value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_value_get_string (&(skeleton->priv->properties[12]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static const gchar *
logind_session_skeleton_get_desktop (LogindSession *object)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);
  const gchar *value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_value_get_string (&(skeleton->priv->properties[13]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static const gchar *
logind_session_skeleton_get_scope (LogindSession *object)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);
  const gchar *value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_value_get_string (&(skeleton->priv->properties[14]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static guint 
logind_session_skeleton_get_leader (LogindSession *object)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);
  guint value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_value_get_uint (&(skeleton->priv->properties[15]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static guint 
logind_session_skeleton_get_audit (LogindSession *object)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);
  guint value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_value_get_uint (&(skeleton->priv->properties[16]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static const gchar *
logind_session_skeleton_get_type_ (LogindSession *object)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);
  const gchar *value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_value_get_string (&(skeleton->priv->properties[17]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static const gchar *
logind_session_skeleton_get_class (LogindSession *object)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);
  const gchar *value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_value_get_string (&(skeleton->priv->properties[18]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static gboolean 
logind_session_skeleton_get_active (LogindSession *object)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);
  gboolean value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_value_get_boolean (&(skeleton->priv->properties[19]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static const gchar *
logind_session_skeleton_get_state (LogindSession *object)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);
  const gchar *value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_value_get_string (&(skeleton->priv->properties[20]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static gboolean 
logind_session_skeleton_get_idle_hint (LogindSession *object)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);
  gboolean value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_value_get_boolean (&(skeleton->priv->properties[21]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static guint64 
logind_session_skeleton_get_idle_since_hint (LogindSession *object)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);
  guint64 value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_value_get_uint64 (&(skeleton->priv->properties[22]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static guint64 
logind_session_skeleton_get_idle_since_hint_monotonic (LogindSession *object)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);
  guint64 value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_value_get_uint64 (&(skeleton->priv->properties[23]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static gboolean 
logind_session_skeleton_get_locked_hint (LogindSession *object)
{
  LogindSessionSkeleton *skeleton = LOGIND_SESSION_SKELETON (object);
  gboolean value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_value_get_boolean (&(skeleton->priv->properties[24]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static void
logind_session_skeleton_class_init (LogindSessionSkeletonClass *klass)
{
  GObjectClass *gobject_class;
  GDBusInterfaceSkeletonClass *skeleton_class;

  gobject_class = G_OBJECT_CLASS (klass);
  gobject_class->finalize = logind_session_skeleton_finalize;
  gobject_class->get_property = logind_session_skeleton_get_property;
  gobject_class->set_property = logind_session_skeleton_set_property;
  gobject_class->notify       = logind_session_skeleton_notify;


  logind_session_override_properties (gobject_class, 1);

  skeleton_class = G_DBUS_INTERFACE_SKELETON_CLASS (klass);
  skeleton_class->get_info = logind_session_skeleton_dbus_interface_get_info;
  skeleton_class->get_properties = logind_session_skeleton_dbus_interface_get_properties;
  skeleton_class->flush = logind_session_skeleton_dbus_interface_flush;
  skeleton_class->get_vtable = logind_session_skeleton_dbus_interface_get_vtable;

#if GLIB_VERSION_MAX_ALLOWED < GLIB_VERSION_2_38
  g_type_class_add_private (klass, sizeof (LogindSessionSkeletonPrivate));
#endif
}

static void
logind_session_skeleton_iface_init (LogindSessionIface *iface)
{
  iface->pause_device = _logind_session_on_signal_pause_device;
  iface->resume_device = _logind_session_on_signal_resume_device;
  iface->lock = _logind_session_on_signal_lock;
  iface->unlock = _logind_session_on_signal_unlock;
  iface->get_id = logind_session_skeleton_get_id;
  iface->get_user = logind_session_skeleton_get_user;
  iface->get_name = logind_session_skeleton_get_name;
  iface->get_timestamp = logind_session_skeleton_get_timestamp;
  iface->get_timestamp_monotonic = logind_session_skeleton_get_timestamp_monotonic;
  iface->get_vtnr = logind_session_skeleton_get_vtnr;
  iface->get_seat = logind_session_skeleton_get_seat;
  iface->get_tty = logind_session_skeleton_get_tty;
  iface->get_display = logind_session_skeleton_get_display;
  iface->get_remote = logind_session_skeleton_get_remote;
  iface->get_remote_host = logind_session_skeleton_get_remote_host;
  iface->get_remote_user = logind_session_skeleton_get_remote_user;
  iface->get_service = logind_session_skeleton_get_service;
  iface->get_desktop = logind_session_skeleton_get_desktop;
  iface->get_scope = logind_session_skeleton_get_scope;
  iface->get_leader = logind_session_skeleton_get_leader;
  iface->get_audit = logind_session_skeleton_get_audit;
  iface->get_type_ = logind_session_skeleton_get_type_;
  iface->get_class = logind_session_skeleton_get_class;
  iface->get_active = logind_session_skeleton_get_active;
  iface->get_state = logind_session_skeleton_get_state;
  iface->get_idle_hint = logind_session_skeleton_get_idle_hint;
  iface->get_idle_since_hint = logind_session_skeleton_get_idle_since_hint;
  iface->get_idle_since_hint_monotonic = logind_session_skeleton_get_idle_since_hint_monotonic;
  iface->get_locked_hint = logind_session_skeleton_get_locked_hint;
}

/**
 * logind_session_skeleton_new:
 *
 * Creates a skeleton object for the D-Bus interface <link linkend="gdbus-interface-org-freedesktop-login1-Session.top_of_page">org.freedesktop.login1.Session</link>.
 *
 * Returns: (transfer full) (type LogindSessionSkeleton): The skeleton object.
 */
LogindSession *
logind_session_skeleton_new (void)
{
  return LOGIND_SESSION (g_object_new (LOGIND_TYPE_SESSION_SKELETON, NULL));
}

